<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => ' ',
    'None' => 'Ei mikään',
    'Edit' => 'Muokkaa',
    'Remove' => 'Poista',
    'Yes' => 'Kyllä',
    'No' => 'Ei',
    'cancel' => 'peruuta',
    'or' => 'tai',
    'Yellow' => 'Keltainen',
    'Blue' => 'Sininen',
    'Green' => 'Vihreä',
    'Purple' => 'Violetti',
    'Red' => 'Punainen',
    'Orange' => 'Oranssi',
    'Grey' => 'Harmaa',
    'Brown' => 'Ruskea',
    'Deep Orange' => 'Tumma oranssi',
    'Dark Grey' => 'Tummanharmaa',
    'Pink' => 'Pinkki',
    'Teal' => 'Sinivihreä',
    'Cyan' => 'Syaani',
    'Lime' => 'Limetin vihreä',
    'Light Green' => 'Vaaleanvihreä',
    'Amber' => 'Keltainen',
    'Save' => 'Tallenna',
    'Login' => 'Sisäänkirjautuminen',
    'Official website:' => 'Virallinen verkkosivu:',
    'Unassigned' => 'Ei suorittajaa',
    'View this task' => 'Näytä tämä tehtävä',
    'Remove user' => 'Poista käyttäjä',
    'Do you really want to remove this user: "%s"?' => 'Oletko varma että haluat poistaa käyttäjän "%s"?',
    'All users' => 'Kaikki käyttäjät',
    'Username' => 'Käyttäjänimi',
    'Password' => 'Salasana',
    'Administrator' => 'Ylläpitäjä',
    'Sign in' => 'Kirjaudu sisään',
    'Users' => 'Käyttäjät',
    'Forbidden' => 'Estetty',
    'Access Forbidden' => 'Pääsy estetty',
    'Edit user' => 'Muokkaa käyttäjää',
    'Logout' => 'Kirjaudu ulos',
    'Bad username or password' => 'Väärä käyttäjätunnus tai salasana',
    'Edit project' => 'Muokkaa projektia',
    'Name' => 'Nimi',
    'Projects' => 'Projektit',
    'No project' => 'Ei projektia',
    'Project' => 'Projekti',
    'Status' => 'Status',
    'Tasks' => 'Tehtävät',
    'Board' => 'Taulu',
    'Actions' => 'Toiminnot',
    'Inactive' => 'Ei aktiivinen',
    'Active' => 'Aktiivinen',
    'Unable to update this board.' => 'Taulun muuttaminen ei onnistunut.',
    'Disable' => 'Disabloi',
    'Enable' => 'Aktivoi',
    'New project' => 'Uusi projekti',
    'Do you really want to remove this project: "%s"?' => 'Haluatko varmasti poistaa projektin: "%s"?',
    'Remove project' => 'Poista projekti',
    'Edit the board for "%s"' => 'Muokkaa taulua projektille "%s"',
    'Add a new column' => 'Lisää uusi sarake',
    'Title' => 'Nimi',
    'Assigned to %s' => 'Tekijä: %s',
    'Remove a column' => 'Poista sarake',
    'Unable to remove this column.' => 'Sarakkeen poistaminen ei onnistunut.',
    'Do you really want to remove this column: "%s"?' => 'Haluatko varmasti poistaa sarakkeen "%s"?',
    'Settings' => 'Asetukset',
    'Application settings' => 'Ohjelman asetukset',
    'Language' => 'Kieli',
    'Webhook token:' => 'Webhooks avain:',
    'API token:' => 'API-tunnus:',
    'Database size:' => 'Tietokannan koko:',
    'Download the database' => 'Lataa tietokanta',
    'Optimize the database' => 'Optimoi tietokanta',
    '(VACUUM command)' => '(VACUUM-komento)',
    '(Gzip compressed Sqlite file)' => '(Gzip-pakattu Sqlite-tiedosto)',
    'Close a task' => 'Sulje tehtävä',
    'Column' => 'Sarake',
    'Color' => 'Väri',
    'Assignee' => 'Suorittaja',
    'Create another task' => 'Luo toinen tehtävä',
    'New task' => 'Uusi tehtävä',
    'Open a task' => 'Avaa tehtävä',
    'Do you really want to open this task: "%s"?' => 'Haluatko varmasti avata tehtävän: "%s"?',
    'Back to the board' => 'Takaisin tauluun',
    'There is nobody assigned' => 'Ei suorittajaa',
    'Column on the board:' => 'Sarake taululla: ',
    'Close this task' => 'Sulje tämä tehtävä',
    'Open this task' => 'Avaa tämä tehtävä',
    'There is no description.' => 'Ei kuvausta.',
    'Add a new task' => 'Lisää uusi tehtävä',
    'The username is required' => 'Käyttäjätunnut vaaditaan',
    'The maximum length is %d characters' => 'Maksimipituus on %d merkkiä',
    'The minimum length is %d characters' => 'Vähimmäispituus on %d merkkiä',
    'The password is required' => 'Salasana vaaditaan',
    'This value must be an integer' => 'Tämän arvon täytyy olla numero',
    'The username must be unique' => 'Käyttäjänimi täytyy olla uniikki',
    'The user id is required' => 'Käyttäjän id on pakollinen',
    'Passwords don\'t match' => 'Salasanat eivät täsmää',
    'The confirmation is required' => 'Varmistus vaaditaan',
    'The project is required' => 'Projekti on pakollinen',
    'The id is required' => 'ID vaaditaan',
    'The project id is required' => 'Projektin ID on pakollinen',
    'The project name is required' => 'Projektin nimi on pakollinen',
    'The title is required' => 'Otsikko vaaditaan',
    'Settings saved successfully.' => 'Asetukset tallennettu onnistuneesti.',
    'Unable to save your settings.' => 'Asetusten tallentaminen epäonnistui.',
    'Database optimization done.' => 'Tietokannan optimointi suoritettu.',
    'Your project has been created successfully.' => 'Projekti luotiin onnistuneesti.',
    'Unable to create your project.' => 'Projektin luominen epäonnistui.',
    'Project updated successfully.' => 'Projekti päivitettiin onnistuneesti.',
    'Unable to update this project.' => 'Projektin muuttaminen epäonnistui.',
    'Unable to remove this project.' => 'Projektin poistaminen epäonnistui.',
    'Project removed successfully.' => 'Projekti poistettiin onnistuneesti.',
    'Project activated successfully.' => 'Projekti aktivoitiin onnistuneesti.',
    'Unable to activate this project.' => 'Projektin aktivoiminen epäonnistui.',
    'Project disabled successfully.' => 'Projektin disabloiminen onnistui.',
    'Unable to disable this project.' => 'Projektin disabloiminen epäonnistui.',
    'Unable to open this task.' => 'Tehtävän avaus epäonnistui.',
    'Task opened successfully.' => 'Tehtävä avattiin onnistuneesti.',
    'Unable to close this task.' => 'Tehtävän sulkeminen epäonnistui.',
    'Task closed successfully.' => 'Tehtävä suljettiin onnistuneesti.',
    'Unable to update your task.' => 'Tehtävän muokkaaminen epäonnistui.',
    'Task updated successfully.' => 'Tehtävä päivitettiin onnistuneesti.',
    'Unable to create your task.' => 'Tehtävän luominen epäonnistui.',
    'Task created successfully.' => 'Tehtävä luotiin onnistuneesti.',
    'User created successfully.' => 'Käyttäjä lisättiin onnistuneesti.',
    'Unable to create your user.' => 'Käyttäjän lisäys epäonnistui.',
    'User updated successfully.' => 'Käyttäjätietojen päivitys onnistui.',
    'User removed successfully.' => 'Käyttäjä poistettiin onnistuneesti.',
    'Unable to remove this user.' => 'Käyttäjän poistaminen epäonnistui.',
    'Board updated successfully.' => 'Taulu päivitettiin onnistuneesti.',
    'Ready' => 'Valmis',
    'Backlog' => 'Tehtäväjono',
    'Work in progress' => 'Työnalla',
    'Done' => 'Tehty',
    'Application version:' => 'Ohjelman versio:',
    'Id' => 'Id',
    'Public link' => 'Julkinen linkki',
    'Timezone' => 'Aikavyöhyke',
    'Sorry, I didn\'t find this information in my database!' => 'Anteeksi, en löytänyt tätä tietoa tietokannastani',
    'Page not found' => 'Sivua ei löydy',
    'Complexity' => 'Monimutkaisuus',
    'Task limit' => 'Tehtävien maksimimäärä',
    'Task count' => 'Tehtävien määrä',
    'User' => 'Käyttäjät',
    'Comments' => 'Kommentit',
    'Comment is required' => 'Kommentti vaaditaan',
    'Comment added successfully.' => 'Kommentti lisättiin onnistuneesti.',
    'Unable to create your comment.' => 'Kommentin lisäys epäonnistui.',
    'Due Date' => 'Deadline',
    'Invalid date' => 'Virheellinen päiväys',
    'Automatic actions' => 'Automaattiset toiminnot',
    'Your automatic action has been created successfully.' => 'Toiminto suoritettiin onnistuneesti.',
    'Unable to create your automatic action.' => 'Automaattisen toiminnon luominen epäonnistui.',
    'Remove an action' => 'Poista toiminto',
    'Unable to remove this action.' => 'Toiminnon poistaminen epäonnistui.',
    'Action removed successfully.' => 'Toiminto poistettiin onnistuneesti.',
    'Automatic actions for the project "%s"' => 'Automaattiset toiminnot projektille "%s"',
    'Add an action' => 'Lisää toiminto',
    'Event name' => 'Tapahtuman nimi',
    'Action' => 'Toiminto',
    'Event' => 'Tapahtuma',
    'When the selected event occurs execute the corresponding action.' => 'Kun valittu tapahtuma tapahtuu, suorita vastaava toiminto.',
    'Next step' => 'Seuraava vaihe',
    'Define action parameters' => 'Määrittele toiminnon parametrit',
    'Do you really want to remove this action: "%s"?' => 'Oletko varma että haluat poistaa toiminnon "%s"?',
    'Remove an automatic action' => 'Poista automaattintn toiminto',
    'Assign the task to a specific user' => 'Osoita tehtävä käyttäjälle',
    'Assign the task to the person who does the action' => 'Määritä suorittaja tehtävälle',
    'Duplicate the task to another project' => 'Monista tehtävä toiselle projektille',
    'Move a task to another column' => 'Siirrä tehtävä toiseen sarakkeeseen',
    'Task modification' => 'Tehtävän muokkaus',
    'Task creation' => 'Tehtävän luominen',
    'Closing a task' => 'Tehtävää suljetaan',
    'Assign a color to a specific user' => 'Valitse väri käyttäjälle',
    'Position' => 'Positio',
    'Duplicate to project' => 'Kopioi toiseen projektiin',
    'Duplicate' => 'Monista',
    'Link' => 'Linkki',
    'Comment updated successfully.' => 'Kommentti päivitettiin onnistuneesti.',
    'Unable to update your comment.' => 'Kommentin päivitys epäonnistui.',
    'Remove a comment' => 'Poista kommentti',
    'Comment removed successfully.' => 'Kommentti poistettiin onnistuneesti.',
    'Unable to remove this comment.' => 'Kommentin poistaminen epäonnistui.',
    'Do you really want to remove this comment?' => 'Haluatko varmasti poistaa tämän kommentin?',
    'Current password for the user "%s"' => 'Käyttäjän "%s" salasana',
    'The current password is required' => 'Salasana vaaditaan',
    'Wrong password' => 'Väärä salasana',
    'Unknown' => 'Tuntematon',
    'Last logins' => 'Viimeisimmät kirjautumiset',
    'Login date' => 'Kirjautumispäivä',
    'Authentication method' => 'Autentikointimenetelmä',
    'IP address' => 'IP-Osoite',
    'User agent' => 'Selain',
    'Persistent connections' => 'Voimassa olevat yhteydet',
    'No session.' => 'Ei sessioita.',
    'Expiration date' => 'Vanhentumispäivä',
    'Remember Me' => 'Muista minut',
    'Creation date' => 'Luomispäivä',
    'Everybody' => 'Kaikki',
    'Open' => 'Avoin',
    'Closed' => 'Suljettu',
    'Search' => 'Etsi',
    'Nothing found.' => 'Ei löytynyt.',
    'Due date' => 'Deadline',
    'Description' => 'Kuvaus',
    '%d comments' => '%d kommenttia',
    '%d comment' => '%d kommentti',
    'Email address invalid' => 'Email ei kelpaa',
    'Your external account is not linked anymore to your profile.' => 'Ulkoinen tilisi ei ole enää linkitetty profiiliisi.',
    'Unable to unlink your external account.' => 'Ulkoisen tilin irrottaminen epäonnistui.',
    'External authentication failed' => 'Ulkoinen tunnistautuminen epäonnistui',
    'Your external account is linked to your profile successfully.' => 'Ulkoinen tilisi on linkitetty profiiliisi onnistuneesti.',
    'Email' => 'Sähköposti',
    'Task removed successfully.' => 'Tehtävä poistettiin onnistuneesti.',
    'Unable to remove this task.' => 'Tehtävän poistaminen epäonnistui.',
    'Remove a task' => 'Poista tehtävä',
    'Do you really want to remove this task: "%s"?' => 'Haluatko varmasti poistaa tehtävän: "%s"?',
    'Assign automatically a color based on a category' => 'Aseta väri automaattisesti kategorian mukaan',
    'Assign automatically a category based on a color' => 'Aseta kategoria automaattisesti värin mukaan',
    'Task creation or modification' => 'Tehtävän luonti tai muuttaminen',
    'Category' => 'Kategoria',
    'Category:' => 'Kategoria:',
    'Categories' => 'Kategoriat',
    'Your category has been created successfully.' => 'Kategoria luotiin onnistuneesti.',
    'This category has been updated successfully.' => 'Kategoriaa muokattiin onnistuneesti.',
    'Unable to update this category.' => 'Kategorian muokkaaminen epäonnistui.',
    'Remove a category' => 'Poista kategoria',
    'Category removed successfully.' => 'Kategoria poistettu onnistuneesti.',
    'Unable to remove this category.' => 'Kategorian poisto epäonnistui.',
    'Category modification for the project "%s"' => 'Kategorian muutos projektissa "%s"',
    'Category Name' => 'Kategorian nimi',
    'Add a new category' => 'Lisää uusi kategoria',
    'Do you really want to remove this category: "%s"?' => 'Haluatko varmasti poistaa kategorian: "%s"?',
    'All categories' => 'Kaikki kategoriat',
    'No category' => 'Kategoriaa ei löydy',
    'The name is required' => 'Nimi vaaditaan',
    'Remove a file' => 'Poista tiedosto',
    'Unable to remove this file.' => 'Tiedoston poistaminen epäonnistui.',
    'File removed successfully.' => 'Tiedosto poistettiin onnistuneesti.',
    'Attach a document' => 'Liitä dokumentti',
    'Do you really want to remove this file: "%s"?' => 'Haluatko varmasti poistaa tiedoston: "%s"?',
    'Attachments' => 'Liitteet',
    'Edit the task' => 'Muokkaa tehtävää',
    'Add a comment' => 'Lisää kommentti',
    'Edit a comment' => 'Muokkaa kommenttia',
    'Summary' => 'Yhteenveto',
    'Time tracking' => 'Ajan seuranta',
    'Estimate:' => 'Arvio:',
    'Spent:' => 'Käytetty:',
    'Do you really want to remove this sub-task?' => 'Haluatko varmasti poistaa tämän alitehtävän?',
    'Remaining:' => 'Jäljellä',
    'hours' => 'tuntia',
    'estimated' => 'estimoitu',
    'Sub-Tasks' => 'Alitehtävät',
    'Add a sub-task' => 'Lisää alitehtävä',
    'Original estimate' => 'Alkuperäinen estimaatti',
    'Create another sub-task' => 'Lisää toinen alitehtävä',
    'Time spent' => 'Käytetty aika',
    'Edit a sub-task' => 'Muokkaa alitehtävää',
    'Remove a sub-task' => 'Poista alitehtävä',
    'The time must be a numeric value' => 'Ajan pitää olla numero',
    'Todo' => 'Todo',
    'In progress' => 'Työnalla',
    'Sub-task removed successfully.' => 'Alitehtävä poistettu onnistuneesti.',
    'Unable to remove this sub-task.' => 'Alitehtävän poistaminen epäonnistui.',
    'Sub-task updated successfully.' => 'Alitehtävä päivitettiin onnistuneesti.',
    'Unable to update your sub-task.' => 'Alitehtävän päivitys epäonnistui.',
    'Unable to create your sub-task.' => 'Alitehtävän luonti epäonnistui.',
    'Maximum size: ' => 'Maksimikoko: ',
    'Display another project' => 'Näytä toinen projekti',
    'Created by %s' => 'Luonut: %s',
    'Tasks Export' => 'Tehtävien vienti',
    'Start Date' => 'Aloituspäivä',
    'Execute' => 'Suorita',
    'Task Id' => 'Tehtävän ID',
    'Creator' => 'Luonut',
    'Modification date' => 'Muokkauspäivä',
    'Completion date' => 'Valmistumispäivä',
    'Clone' => 'Kahdenna',
    'Project cloned successfully.' => 'Projekti kahdennettu onnistuneesti',
    'Unable to clone this project.' => 'Projektin kahdennus epäonnistui',
    'Enable email notifications' => 'Ota käyttöön sähköposti-ilmoitukset',
    'Task position:' => 'Tehtävän sijainti',
    'The task #%d has been opened.' => 'Tehtävä #%d on avattu',
    'The task #%d has been closed.' => 'Tehtävä #%d on suljettu',
    'Sub-task updated' => 'Alitehtävä päivitetty',
    'Title:' => 'Otsikko:',
    'Status:' => 'Tila:',
    'Assignee:' => 'Vastaanottaja:',
    'Time tracking:' => 'Ajan seuranta:',
    'New sub-task' => 'Uusi alitehtävä',
    'New attachment added "%s"' => 'Uusi liite lisätty "%s"',
    'New comment posted by %s' => '%s lisäsi uuden kommentin',
    'New comment' => 'Uusi kommentti',
    'Comment updated' => 'Kommentti päivitetty',
    'New subtask' => 'Uusi alitehtävä',
    'I only want to receive notifications for these projects:' => 'Haluan vastaanottaa ilmoituksia ainoastaan näistä projekteista:',
    'view the task on Kanboard' => 'katso tehtävää Kanboardissa',
    'Public access' => 'Julkinen käyttöoikeus',
    'Disable public access' => 'Poista käytöstä julkinen käyttöoikeus',
    'Enable public access' => 'Ota käyttöön ',
    'Public access disabled' => 'Julkinen käyttöoikeus ei ole käytössä',
    'Move the task to another project' => 'Siirrä tehtävä toiseen projektiin',
    'Move to project' => 'Siirrä toiseen projektiin',
    'Do you really want to duplicate this task?' => 'Haluatko varmasti kahdentaa tämän tehtävän?',
    'Duplicate a task' => 'Kahdenna tehtävä',
    'External accounts' => 'Muut tilit',
    'Account type' => 'Tilin tyyppi',
    'Local' => 'Paikallinen',
    'Remote' => 'Etä',
    'Enabled' => 'Käytössä',
    'Disabled' => 'Pois käytöstä',
    'Login:' => 'Käyttäjänimi:',
    'Full Name:' => 'Nimi:',
    'Email:' => 'Sähköpostiosoite:',
    'Notifications:' => 'Ilmoitukset:',
    'Notifications' => 'Ilmoitukset',
    'Account type:' => 'Tilin tyyppi:',
    'Edit profile' => 'Muokkaa profiilia',
    'Change password' => 'Vaihda salasana',
    'Password modification' => 'Salasanan vaihto',
    'External authentications' => 'Muut tunnistautumistavat',
    'Never connected.' => 'Ei koskaan liitetty.',
    'No external authentication enabled.' => 'Muita tunnistautumistapoja ei ole otettu käyttöön.',
    'Password modified successfully.' => 'Salasana vaihdettu onnistuneesti.',
    'Unable to change the password.' => 'Salasanan vaihto epäonnistui.',
    'Change category' => 'Vaihda kategoria',
    '%s updated the task %s' => '%s päivitti tehtävän %s',
    '%s opened the task %s' => '%s avasi tehtävän %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s siirsi tehtävän %s %d. sarakkeessa "%s"',
    '%s moved the task %s to the column "%s"' => '%s siirsi tehtävän %s sarakkeeseen "%s"',
    '%s created the task %s' => '%s loi tehtävän %s',
    '%s closed the task %s' => '%s sulki tehtävän %s',
    '%s created a subtask for the task %s' => '%s loi alitehtävän tehtävälle %s',
    '%s updated a subtask for the task %s' => '%s päivitti tehtävän %s alitehtävää',
    'Assigned to %s with an estimate of %s/%sh' => 'Annettu henkilölle %s arviolla %s/%sh',
    'Not assigned, estimate of %sh' => 'Ei annettu kenellekään, arvio %sh',
    '%s updated a comment on the task %s' => '%s päivitti kommentia tehtävässä %s',
    '%s commented the task %s' => '%s kommentoi tehtävää %s',
    '%s\'s activity' => 'Henkilön %s toiminta',
    'RSS feed' => 'RSS-syöte',
    '%s updated a comment on the task #%d' => '%s päivitti kommenttia tehtävässä #%d',
    '%s commented on the task #%d' => '%s kommentoi tehtävää #%d',
    '%s updated a subtask for the task #%d' => '%s päivitti tehtävän #%d alitehtävää',
    '%s created a subtask for the task #%d' => '%s loi alitehtävän tehtävälle #%d',
    '%s updated the task #%d' => '%s päivitti tehtävää #%d',
    '%s created the task #%d' => '%s loi tehtävän #%d',
    '%s closed the task #%d' => '%s sulki tehtävän #%d',
    '%s opened the task #%d' => '%s avasi tehtävän #%d',
    'Activity' => 'Toiminta',
    'Default values are "%s"' => 'Oletusarvot ovat "%s"',
    'Default columns for new projects (Comma-separated)' => 'Oletussarakkeet uusille projekteille',
    'Task assignee change' => 'Tehtävän saajan vaihto',
    '%s changed the assignee of the task #%d to %s' => '%s vaihtoi tehtävän #%d saajaksi %s',
    '%s changed the assignee of the task %s to %s' => '%s vaihtoi tehtävän %s saajaksi %s',
    'New password for the user "%s"' => 'Uusi salasana käyttäjälle "%s"',
    'Choose an event' => 'Valitse toiminta',
    'Create a task from an external provider' => 'Luo tehtävä ulkoiselta tarjoajalta',
    'Change the assignee based on an external username' => 'Vaihda tehtävän saajaa perustuen ulkoiseen käyttäjänimeen',
    'Change the category based on an external label' => 'Vaihda kategoriaa perustuen ulkoiseen labeliin',
    'Reference' => 'Viite',
    'Label' => 'Label',
    'Database' => 'Tietokanta',
    'About' => 'Tietoja',
    'Database driver:' => 'Tietokantaohjelmisto:',
    'Board settings' => 'Taulun asetukset',
    'Webhook settings' => 'Webhookin asetukset',
    'Reset token' => 'Vaihda token',
    'API endpoint:' => 'API päätepiste:',
    'Refresh interval for personal board' => 'Päivitystiheys yksityisille tauluille',
    'Refresh interval for public board' => 'Päivitystiheys julkisille tauluille',
    'Task highlight period' => 'Tehtävän korostusaika',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Aika (sekunteina) kuinka kauan tehtävä voidaan katsoa äskettäin muokatuksi (0 poistaa toiminnon käytöstä, oletuksena 2 päivää)',
    'Frequency in second (60 seconds by default)' => 'Päivitystiheys sekunteina (60 sekuntia oletuksena)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Päivitystiheys sekunteina (0 poistaa toiminnon käytöstä, oletuksena 10 sekuntia)',
    'Application URL' => 'Sovelluksen URL',
    'Token regenerated.' => 'Token uudelleenluotu.',
    'Date format' => 'Päiväyksen muoto',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO-muoto on aina hyväksytty, esimerkiksi %s ja %s',
    'New personal project' => 'Uusi henkilökohtainen projekti',
    'This project is personal' => 'Tämä projekti on henkilökohtainen',
    'Add' => 'Lisää',
    'Start date' => 'Aloituspäivä',
    'Time estimated' => 'Arvioitu aika',
    'There is nothing assigned to you.' => 'Ei tehtäviä, joihin sinut olisi merkitty tekijäksi.',
    'My tasks' => 'Minun tehtävät',
    'Activity stream' => 'Toiminta',
    'Dashboard' => 'Työpöytä',
    'Confirmation' => 'Vahvistus',
    'Webhooks' => 'Webhookit',
    'API' => 'API',
    'Create a comment from an external provider' => 'Luo kommentti ulkoiselta palveluntarjoajalta',
    'Project management' => 'Projektin hallinta',
    'Columns' => 'Sarakkeet',
    'Task' => 'Tehtävät',
    'Percentage' => 'Prosentti',
    'Number of tasks' => 'Tehtävien määrä',
    'Task distribution' => 'Tehtävien jakauma',
    'Analytics' => 'Analytiikka',
    'Subtask' => 'Alitehtävä',
    'User repartition' => 'Käyttäjien jakauma',
    'Clone this project' => 'Kahdenna projekti',
    'Column removed successfully.' => 'Sarake poistettu onnstuneesti.',
    'Not enough data to show the graph.' => 'Ei riittävästi dataa graafin näyttämiseksi.',
    'Previous' => 'Edellinen',
    'The id must be an integer' => 'ID:n on oltava kokonaisluku',
    'The project id must be an integer' => 'Projektin ID:n on oltava kokonaisluku',
    'The status must be an integer' => 'Tilan on oltava kokonaisluku',
    'The subtask id is required' => 'Alitehtävän ID vaaditaan',
    'The subtask id must be an integer' => 'Alitehtävän ID:ntulee olla kokonaisluku',
    'The task id is required' => 'Tehtävän ID vaaditaan',
    'The task id must be an integer' => 'Tehtävän ID on oltava kokonaisluku',
    'The user id must be an integer' => 'Käyttäjän ID on oltava kokonaisluku',
    'This value is required' => 'Tämä arvo on pakollinen',
    'This value must be numeric' => 'Tämän arvon tulee olla numeerinen',
    'Unable to create this task.' => 'Tehtävän luonti epäonnistui',
    'Cumulative flow diagram' => 'Kumulatiivinen vuokaavio',
    'Daily project summary' => 'Päivittäinen yhteenveto',
    'Daily project summary export' => 'Päivittäisen yhteenvedon vienti',
    'Exports' => 'Viennit',
    'This export contains the number of tasks per column grouped per day.' => 'Tämä tiedosto sisältää tehtäviä sarakkeisiin päiväkohtaisesti ryhmilteltyinä',
    'Active swimlanes' => 'Aktiiviset kaistat',
    'Add a new swimlane' => 'Lisää uusi kaista',
    'Default swimlane' => 'Oletuskaista',
    'Do you really want to remove this swimlane: "%s"?' => 'Haluatko varmasti poistaa tämän kaistan: "%s"?',
    'Inactive swimlanes' => 'Passiiviset kaistat',
    'Remove a swimlane' => 'Poista kaista',
    'Swimlane modification for the project "%s"' => 'Kaistamuutos projektille "%s"',
    'Swimlane removed successfully.' => 'Kaista poistettu onnistuneesti.',
    'Swimlanes' => 'Kaistat',
    'Swimlane updated successfully.' => 'Kaista päivitetty onnistuneesti.',
    'Unable to remove this swimlane.' => 'Kaistan poisto epäonnistui.',
    'Unable to update this swimlane.' => 'Kaistan päivittäminen epäonnistui.',
    'Your swimlane has been created successfully.' => 'Kaista luotu onnistuneesti.',
    'Example: "Bug, Feature Request, Improvement"' => 'Esimerkiksi: "Bugit, Ominaisuuspyynnöt, Parannukset"',
    'Default categories for new projects (Comma-separated)' => 'Oletuskategoriat uusille projekteille (pilkuin eroteltu)',
    'Integrations' => 'Integraatiot',
    'Integration with third-party services' => 'Integrointi kolmannen osapuolen palveluihin',
    'Subtask Id' => 'Alitehtävän tunnus',
    'Subtasks' => 'Alitehtävät',
    'Subtasks Export' => 'Alitehtävien vienti',
    'Task Title' => 'Tehtävän otsikko',
    'Untitled' => 'Nimetön',
    'Application default' => 'Sovelluksen oletus',
    'Language:' => 'Kieli:',
    'Timezone:' => 'Aikavyöhyke:',
    'All columns' => 'Kaikki sarakkeet',
    'Next' => 'Seuraava',
    '#%d' => '#%d',
    'All swimlanes' => 'Kaikki kaistat',
    'All colors' => 'Kaikki värit',
    'Moved to column %s' => 'Siirretty sarakkeeseen %s',
    'User dashboard' => 'Käyttäjän hallintapaneeli',
    'Allow only one subtask in progress at the same time for a user' => 'Salli käyttäjälle vain yksi alitehtävä kerrallaan kesken',
    'Edit column "%s"' => 'Muokkaa saraketta "%s"',
    'Select the new status of the subtask: "%s"' => 'Valitse alitehtävän uusi tila: "%s"',
    'Subtask timesheet' => 'Alitehtävien tuntilista',
    'There is nothing to show.' => 'Ei näytettävää.',
    'Time Tracking' => 'Ajankäytön seuranta',
    'You already have one subtask in progress' => 'Sinulla on jo yksi alitehtävä kesken',
    'Which parts of the project do you want to duplicate?' => 'Mitkä osat projektista haluat kopioida?',
    'Disallow login form' => 'Estä kirjautumislomake',
    'Start' => 'Alku',
    'End' => 'Loppu',
    'Task age in days' => 'Tehtävän ikä päivinä',
    'Days in this column' => 'Päivää tässä sarakkeessa',
    '%dd' => '%dp',
    'Add a new link' => 'Lisää uusi linkki',
    'Do you really want to remove this link: "%s"?' => 'Haluatko todella poistaa tämän linkin: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Haluatko todella poistaa tämän linkin tehtävään #%d?',
    'Field required' => 'Kenttä on pakollinen',
    'Link added successfully.' => 'Linkki lisättiin onnistuneesti.',
    'Link updated successfully.' => 'Linkki päivitettiin onnistuneesti.',
    'Link removed successfully.' => 'Linkki poistettiin onnistuneesti.',
    'Link labels' => 'Linkkien selitteet',
    'Link modification' => 'Linkin muokkaus',
    'Opposite label' => 'Vastakkainen selite',
    'Remove a link' => 'Poista linkki',
    'The labels must be different' => 'Selitteiden on oltava erilaisia',
    'There is no link.' => 'Ei linkkejä.',
    'This label must be unique' => 'Tämän selitteen on oltava yksilöllinen',
    'Unable to create your link.' => 'Linkin luominen epäonnistui.',
    'Unable to update your link.' => 'Linkin päivittäminen epäonnistui.',
    'Unable to remove this link.' => 'Linkin poistaminen epäonnistui.',
    'relates to' => 'liittyy',
    'blocks' => 'estää',
    'is blocked by' => 'estää',
    'duplicates' => 'kopioi',
    'is duplicated by' => 'on kopioitu',
    'is a child of' => 'on alitehtävä',
    'is a parent of' => 'on ylätason tehtävä',
    'targets milestone' => 'kohdistuu välitavoitteeseen',
    'is a milestone of' => 'on välitavoite',
    'fixes' => 'korjaa',
    'is fixed by' => 'korjaa',
    'This task' => 'Tämä tehtävä',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Laajenna tehtävät',
    'Collapse tasks' => 'Kutista tehtävät',
    'Expand/collapse tasks' => 'Laajenna/kutista tehtävät',
    'Close dialog box' => 'Sulje valintaikkuna',
    'Submit a form' => 'Lähetä lomake',
    'Board view' => 'Taulunäkymä',
    'Keyboard shortcuts' => 'Pikanäppäimet',
    'Open board switcher' => 'Avaa taulun valitsin',
    'Application' => 'Sovellus',
    'Compact view' => 'Tiivis näkymä',
    'Horizontal scrolling' => 'Vaakavieritys',
    'Compact/wide view' => 'Tiivis/leveä näkymä',
    'Currency' => 'Valuutta',
    'Personal project' => 'Henkilökohtainen projekti',
    'AUD - Australian Dollar' => 'AUD - Australian dollari',
    'CAD - Canadian Dollar' => 'CAD - Kanadan dollari',
    'CHF - Swiss Francs' => 'CHF - Sveitsin frangi',
    'Custom Stylesheet' => 'Mukautettu tyylitiedosto',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Englannin punta',
    'INR - Indian Rupee' => 'INR - Intian rupia',
    'JPY - Japanese Yen' => 'JPY - Japanin jeni',
    'NZD - New Zealand Dollar' => 'NZD - Uuden-Seelannin dollari',
    'PEN - Peruvian Sol' => 'Perun sol',
    'RSD - Serbian dinar' => 'RSD - Serbian dinaari',
    'CNY - Chinese Yuan' => 'CNY - Kiinan yuan',
    'USD - US Dollar' => 'USD - Yhdysvaltain dollari',
    'VES - Venezuelan Bolívar' => 'VES - Venezuelan bolívar',
    'Destination column' => 'Kohdesarake',
    'Move the task to another column when assigned to a user' => 'Siirrä tehtävä toiseen sarakkeeseen, kun se on määritetty käyttäjälle',
    'Move the task to another column when assignee is cleared' => 'Siirrä tehtävä toiseen sarakkeeseen, kun määräys on poistettu',
    'Source column' => 'Lähdesarake',
    'Transitions' => 'Siirtymät',
    'Executer' => 'Suorittaja',
    'Time spent in the column' => 'Aika, joka on käytetty sarakkeessa',
    'Task transitions' => 'Tehtävän siirtymät',
    'Task transitions export' => 'Tehtävän siirtymien vienti',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Tämä raportti sisältää kaikki sarakkeiden siirtymät kullekin tehtävälle päivämäärän, käyttäjän ja kunkin siirtymän käytetyn ajan kanssa.',
    'Currency rates' => 'Valuuttakurssit',
    'Rate' => 'Kurssi',
    'Change reference currency' => 'Vaihda vertailuvaluutta',
    'Reference currency' => 'Vertailuvaluutta',
    'The currency rate has been added successfully.' => 'Valuuttakurssi lisättiin onnistuneesti.',
    'Unable to add this currency rate.' => 'Valuuttakurssia ei voitu lisätä.',
    'Webhook URL' => 'Webhook URL',
    '%s removed the assignee of the task %s' => '%s poisti tehtävän %s määräyksen',
    'Information' => 'Tietoja',
    'Check two factor authentication code' => 'Tarkista kaksivaiheisen tunnistautumisen koodi',
    'The two factor authentication code is not valid.' => 'Kaksivaiheisen tunnistautumisen koodi ei ole kelvollinen.',
    'The two factor authentication code is valid.' => 'Kaksivaiheisen tunnistautumisen koodi on kelvollinen.',
    'Code' => 'Koodi',
    'Two factor authentication' => 'Kaksivaiheinen tunnistautuminen',
    'This QR code contains the key URI: ' => 'Tämä QR-koodi sisältää avaimen URI:n:',
    'Check my code' => 'Tarkista koodini',
    'Secret key: ' => 'Salainen avain:',
    'Test your device' => 'Testaa laitettasi',
    'Assign a color when the task is moved to a specific column' => 'Määritä väri, kun tehtävä siirretään tiettyyn sarakkeeseen',
    '%s via Kanboard' => '%s Kanboardin kautta',
    'Burndown chart' => 'Burndown-kaavio',
    'This chart show the task complexity over the time (Work Remaining).' => 'Tämä kaavio näyttää tehtävän monimutkaisuuden ajan myötä (Jäljellä oleva työ).',
    'Screenshot taken %s' => 'Kuvakaappaus otettu %s',
    'Add a screenshot' => 'Lisää kuvakaappaus',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Ota kuvakaappaus ja paina CTRL+V tai ⌘+V liittääksesi sen tähän.',
    'Screenshot uploaded successfully.' => 'Kuvakaappaus ladattiin onnistuneesti.',
    'SEK - Swedish Krona' => 'SEK - Ruotsin kruunu',
    'Identifier' => 'Tunnus',
    'Disable two factor authentication' => 'Poista kaksivaiheinen tunnistautuminen käytöstä',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Haluatko todella poistaa kaksivaiheisen tunnistautumisen käytöstä tälle käyttäjälle: "%s"?',
    'Edit link' => 'Muokkaa linkkiä',
    'Start to type task title...' => 'Aloita tehtävän otsikon kirjoittaminen...',
    'A task cannot be linked to itself' => 'Tehtävää ei voida linkittää itseensä',
    'The exact same link already exists' => 'Täsmälleen sama linkki on jo olemassa',
    'Recurrent task is scheduled to be generated' => 'Toistuva tehtävä on ajoitettu luotavaksi',
    'Score' => 'Pisteet',
    'The identifier must be unique' => 'Tunnuksen on oltava yksilöllinen',
    'This linked task id doesn\'t exists' => 'Tätä linkitettyä tehtävän tunnusta ei ole olemassa',
    'This value must be alphanumeric' => 'Tämän arvon on oltava aakkosnumeerinen',
    'Edit recurrence' => 'Muokkaa toistuvuutta',
    'Generate recurrent task' => 'Luo toistuva tehtävä',
    'Trigger to generate recurrent task' => 'Laukaisin toistuvan tehtävän luomiseksi',
    'Factor to calculate new due date' => 'Tekijä uuden määräpäivän laskemiseksi',
    'Timeframe to calculate new due date' => 'Aikataulu uuden määräpäivän laskemiseksi',
    'Base date to calculate new due date' => 'Peruspäivämäärä uuden määräpäivän laskemiseksi',
    'Action date' => 'Toiminnon päivämäärä',
    'Base date to calculate new due date: ' => 'Peruspäivämäärä uuden määräpäivän laskemiseksi:',
    'This task has created this child task: ' => 'Tämä tehtävä on luonut tämän alitehtävän:',
    'Day(s)' => 'Päivä(t)',
    'Existing due date' => 'Olemassa oleva määräpäivä',
    'Factor to calculate new due date: ' => 'Tekijä uuden määräpäivän laskemiseksi:',
    'Month(s)' => 'Kuukausi(t)',
    'This task has been created by: ' => 'Tämän tehtävän on luonut:',
    'Recurrent task has been generated:' => 'Toistuva tehtävä on luotu:',
    'Timeframe to calculate new due date: ' => 'Aikataulu uuden määräpäivän laskemiseksi:',
    'Trigger to generate recurrent task: ' => 'Laukaisin toistuvan tehtävän luomiseksi:',
    'When task is closed' => 'Kun tehtävä suljetaan',
    'When task is moved from first column' => 'Kun tehtävä siirretään ensimmäisestä sarakkeesta',
    'When task is moved to last column' => 'Kun tehtävä siirretään viimeiseen sarakkeeseen',
    'Year(s)' => 'Vuosi(t)',
    'Project settings' => 'Projektin asetukset',
    'Automatically update the start date' => 'Päivitä aloituspäivämäärä automaattisesti',
    'iCal feed' => 'iCal-syöte',
    'Preferences' => 'Asetukset',
    'Security' => 'Turvallisuus',
    'Two factor authentication disabled' => 'Kaksivaiheinen tunnistautuminen poistettu käytöstä',
    'Two factor authentication enabled' => 'Kaksivaiheinen tunnistautuminen käytössä',
    'Unable to update this user.' => 'Tämän käyttäjän päivittäminen epäonnistui.',
    'There is no user management for personal projects.' => 'Henkilökohtaisissa projekteissa ei ole käyttäjien hallintaa.',
    'User that will receive the email' => 'Käyttäjä, joka vastaanottaa sähköpostin',
    'Email subject' => 'Sähköpostin aihe',
    'Date' => 'Päivämäärä',
    'Add a comment log when moving the task between columns' => 'Lisää kommenttiloki, kun tehtävää siirretään sarakkeiden välillä',
    'Move the task to another column when the category is changed' => 'Siirrä tehtävä toiseen sarakkeeseen, kun luokkaa muutetaan',
    'Send a task by email to someone' => 'Lähetä tehtävä sähköpostitse jollekin',
    'Reopen a task' => 'Avaa tehtävä uudelleen',
    'Notification' => 'Ilmoitus',
    '%s moved the task #%d to the first swimlane' => '%s siirsi tehtävän #%d ensimmäiseen kaistaan',
    'Swimlane' => 'Kaista',
    '%s moved the task %s to the first swimlane' => '%s siirsi tehtävän %s ensimmäiseen kaistaan',
    '%s moved the task %s to the swimlane "%s"' => '%s siirsi tehtävän %s kaistaan "%s"',
    'This report contains all subtasks information for the given date range.' => 'Tämä raportti sisältää kaikki alitehtävien tiedot annetulta aikaväliltä.',
    'This report contains all tasks information for the given date range.' => 'Tämä raportti sisältää kaikki tehtävien tiedot annetulta aikaväliltä.',
    'Project activities for %s' => 'Projektin aktiviteetit käyttäjälle %s',
    'view the board on Kanboard' => 'katso taulua Kanboardissa',
    'The task has been moved to the first swimlane' => 'Tehtävä on siirretty ensimmäiseen kaistaan',
    'The task has been moved to another swimlane:' => 'Tehtävä on siirretty toiseen kaistaan:',
    'New title: %s' => 'Uusi otsikko: %s',
    'The task is not assigned anymore' => 'Tehtävää ei ole enää määritetty',
    'New assignee: %s' => 'Uusi määrätty: %s',
    'There is no category now' => 'Ei luokkaa nyt',
    'New category: %s' => 'Uusi luokka: %s',
    'New color: %s' => 'Uusi väri: %s',
    'New complexity: %d' => 'Uusi monimutkaisuus: %d',
    'The due date has been removed' => 'Määräpäivä on poistettu',
    'There is no description anymore' => 'Kuvausta ei ole enää',
    'Recurrence settings has been modified' => 'Toistuvuuden asetuksia on muutettu',
    'Time spent changed: %sh' => 'Käytetty aika muuttui: %sh',
    'Time estimated changed: %sh' => 'Arvioitu aika muuttui: %sh',
    'The field "%s" has been updated' => 'Kenttä "%s" on päivitetty',
    'The description has been modified:' => 'Kuvaus on muokattu:',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Haluatko todella sulkea tehtävän "%s" ja kaikki alitehtävät?',
    'I want to receive notifications for:' => 'Haluan vastaanottaa ilmoituksia:',
    'All tasks' => 'Kaikki tehtävät',
    'Only for tasks assigned to me' => 'Vain minulle määritetyistä tehtävistä',
    'Only for tasks created by me' => 'Vain minun luomistani tehtävistä',
    'Only for tasks created by me and tasks assigned to me' => 'Vain minun luomistani tehtävistä ja minulle määritetyistä tehtävistä',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => 'Yhteensä kaikille sarakkeille',
    'You need at least 2 days of data to show the chart.' => 'Tarvitset vähintään 2 päivän tiedot kaavion näyttämiseksi.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Pysäytä ajastin',
    'Start timer' => 'Käynnistä ajastin',
    'My activity stream' => 'Oma aktiviteettivirta',
    'Search tasks' => 'Hae tehtäviä',
    'Reset filters' => 'Nollaa suodattimet',
    'My tasks due tomorrow' => 'Tehtäväni, jotka ovat huomenna määräpäivä',
    'Tasks due today' => 'Tehtävät, jotka ovat tänään määräpäivä',
    'Tasks due tomorrow' => 'Tehtävät, jotka ovat huomenna määräpäivä',
    'Tasks due yesterday' => 'Tehtävät, jotka olivat eilen määräpäivä',
    'Closed tasks' => 'Suljetut tehtävät',
    'Open tasks' => 'Avoimet tehtävät',
    'Not assigned' => 'Ei määritetty',
    'View advanced search syntax' => 'Näytä tarkennetun haun syntaksi',
    'Overview' => 'Yleiskatsaus',
    'Board/Calendar/List view' => 'Taulu/Kalenteri/Lista-näkymä',
    'Switch to the board view' => 'Vaihda taulunäkymään',
    'Switch to the list view' => 'Vaihda listanäkymään',
    'Go to the search/filter box' => 'Siirry haku/suodatin-kenttään',
    'There is no activity yet.' => 'Ei vielä toimintaa.',
    'No tasks found.' => 'Tehtäviä ei löytynyt.',
    'Keyboard shortcut: "%s"' => 'Pikanäppäin: "%s"',
    'List' => 'Lista',
    'Filter' => 'Suodatin',
    'Advanced search' => 'Tarkennettu haku',
    'Example of query: ' => 'Esimerkki kyselystä:',
    'Search by project: ' => 'Hae projektin mukaan:',
    'Search by column: ' => 'Hae sarakkeen mukaan:',
    'Search by assignee: ' => 'Hae määrätyn mukaan:',
    'Search by color: ' => 'Hae värin mukaan:',
    'Search by category: ' => 'Hae luokan mukaan:',
    'Search by description: ' => 'Hae kuvauksen mukaan:',
    'Search by due date: ' => 'Hae määräpäivän mukaan:',
    'Average time spent in each column' => 'Keskimääräinen aika, joka on käytetty kussakin sarakkeessa',
    'Average time spent' => 'Keskimääräinen käytetty aika',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Tämä kaavio näyttää keskimääräisen ajan, joka on käytetty kussakin sarakkeessa viimeisimmän %d tehtävän osalta.',
    'Average Lead and Cycle time' => 'Keskimääräinen läpimeno- ja sykliaika',
    'Average lead time: ' => 'Keskimääräinen läpimenoaika:',
    'Average cycle time: ' => 'Keskimääräinen sykliaika:',
    'Cycle Time' => 'Sykliaika',
    'Lead Time' => 'Läpimenoaika',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Tämä kaavio näyttää keskimääräisen läpimeno- ja sykliajan viimeisimmän %d tehtävän osalta ajan myötä.',
    'Average time into each column' => 'Keskimääräinen aika kuhunkin sarakkeeseen',
    'Lead and cycle time' => 'Läpimeno- ja sykliaika',
    'Lead time: ' => 'Läpimenoaika:',
    'Cycle time: ' => 'Sykliaika:',
    'Time spent in each column' => 'Aika, joka on käytetty kussakin sarakkeessa',
    'The lead time is the duration between the task creation and the completion.' => 'Läpimenoaika on tehtävän luomisen ja valmistumisen välinen kesto.',
    'The cycle time is the duration between the start date and the completion.' => 'Sykliaika on aloituspäivämäärän ja valmistumisen välinen kesto.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Jos tehtävää ei ole suljettu, käytetään nykyistä aikaa valmistumispäivämäärän sijaan.',
    'Set the start date automatically' => 'Aseta aloituspäivämäärä automaattisesti',
    'Edit Authentication' => 'Muokkaa tunnistautumista',
    'Remote user' => 'Etäkäyttäjä',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Etäkäyttäjät eivät tallenna salasanaansa Kanboard-tietokantaan, esimerkiksi: LDAP-, Google- ja Github-tilit.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Jos valitset ruudun "Älä salli kirjautumislomaketta", kirjautumislomakkeeseen syötetyt tunnukset ohitetaan.',
    'Default task color' => 'Tehtävän oletusväri',
    'This feature does not work with all browsers.' => 'Tämä ominaisuus ei toimi kaikilla selaimilla.',
    'There is no destination project available.' => 'Ei käytettävissä olevaa kohdeprojektia.',
    'Trigger automatically subtask time tracking' => 'Käynnistä automaattisesti alitehtävän ajankäytön seuranta',
    'Include closed tasks in the cumulative flow diagram' => 'Sisällytä suljetut tehtävät kumulatiiviseen virtauskaavioon',
    'Current swimlane: %s' => 'Nykyinen kaista: %s',
    'Current column: %s' => 'Nykyinen sarake: %s',
    'Current category: %s' => 'Nykyinen luokka: %s',
    'no category' => 'ei luokkaa',
    'Current assignee: %s' => 'Nykyinen määrätty: %s',
    'not assigned' => 'ei määritetty',
    'Author:' => 'Tekijä:',
    'contributors' => 'avustajat',
    'License:' => 'Lisenssi:',
    'License' => 'Lisenssi',
    'Enter the text below' => 'Syötä teksti alle',
    'Start date:' => 'Aloituspäivämäärä:',
    'Due date:' => 'Määräpäivä:',
    'People who are project managers' => 'Henkilöt, jotka ovat projektipäälliköitä',
    'People who are project members' => 'Henkilöt, jotka ovat projektin jäseniä',
    'NOK - Norwegian Krone' => 'NOK - Norjan kruunu',
    'Show this column' => 'Näytä tämä sarake',
    'Hide this column' => 'Piilota tämä sarake',
    'End date' => 'Lopetuspäivämäärä',
    'Users overview' => 'Käyttäjien yleiskatsaus',
    'Members' => 'Jäsenet',
    'Shared project' => 'Jaettu projekti',
    'Project managers' => 'Projektipäälliköt',
    'Projects list' => 'Projektilista',
    'End date:' => 'Lopetuspäivämäärä:',
    'Change task color when using a specific task link' => 'Muuta tehtävän väriä, kun käytetään tiettyä tehtävälinkkiä',
    'Task link creation or modification' => 'Tehtävälinkin luominen tai muokkaus',
    'Milestone' => 'Välitavoite',
    'Reset the search/filter box' => 'Nollaa haku/suodatin-kenttä',
    'Documentation' => 'Dokumentaatio',
    'Author' => 'Tekijä',
    'Version' => 'Versio',
    'Plugins' => 'Lisäosat',
    'There is no plugin loaded.' => 'Lisäosia ei ole ladattu.',
    'My notifications' => 'Omat ilmoitukset',
    'Custom filters' => 'Mukautetut suodattimet',
    'Your custom filter has been created successfully.' => 'Mukautettu suodatin on luotu onnistuneesti.',
    'Unable to create your custom filter.' => 'Mukautettua suodatinta ei voitu luoda.',
    'Custom filter removed successfully.' => 'Mukautettu suodatin poistettiin onnistuneesti.',
    'Unable to remove this custom filter.' => 'Mukautetun suodattimen poistaminen epäonnistui.',
    'Edit custom filter' => 'Muokkaa mukautettua suodatinta',
    'Your custom filter has been updated successfully.' => 'Mukautettu suodatin on päivitetty onnistuneesti.',
    'Unable to update custom filter.' => 'Mukautetun suodattimen päivittäminen epäonnistui.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Uusi liite tehtävässä #%d: %s',
    'New comment on task #%d' => 'Uusi kommentti tehtävässä #%d',
    'Comment updated on task #%d' => 'Kommentti päivitetty tehtävässä #%d',
    'New subtask on task #%d' => 'Uusi alitehtävä tehtävässä #%d',
    'Subtask updated on task #%d' => 'Alitehtävä päivitetty tehtävässä #%d',
    'New task #%d: %s' => 'Uusi tehtävä #%d: %s',
    'Task updated #%d' => 'Tehtävä päivitetty #%d',
    'Task #%d closed' => 'Tehtävä #%d suljettu',
    'Task #%d opened' => 'Tehtävä #%d avattu',
    'Column changed for task #%d' => 'Sarake muutettu tehtävälle #%d',
    'New position for task #%d' => 'Uusi sijainti tehtävälle #%d',
    'Swimlane changed for task #%d' => 'Kaista muutettu tehtävälle #%d',
    'Assignee changed on task #%d' => 'Määräys muutettu tehtävässä #%d',
    '%d overdue tasks' => '%d myöhässä olevaa tehtävää',
    'No notification.' => 'Ei ilmoituksia.',
    'Mark all as read' => 'Merkitse kaikki luetuksi',
    'Mark as read' => 'Merkitse luetuksi',
    'Total number of tasks in this column across all swimlanes' => 'Tehtävien kokonaismäärä tässä sarakkeessa kaikilla kaistoilla',
    'Collapse swimlane' => 'Kutista kaista',
    'Expand swimlane' => 'Laajenna kaista',
    'Add a new filter' => 'Lisää uusi suodatin',
    'Share with all project members' => 'Jaa kaikille projektin jäsenille',
    'Shared' => 'Jaettu',
    'Owner' => 'Omistaja',
    'Unread notifications' => 'Lukemattomat ilmoitukset',
    'Notification methods:' => 'Ilmoitusmenetelmät:',
    'Unable to read your file' => 'Tiedostoa ei voitu lukea',
    '%d task(s) have been imported successfully.' => '%d tehtävä(t) on tuotu onnistuneesti.',
    'Nothing has been imported!' => 'Mitään ei ole tuotu!',
    'Import users from CSV file' => 'Tuo käyttäjät CSV-tiedostosta',
    '%d user(s) have been imported successfully.' => '%d käyttäjä(t) on tuotu onnistuneesti.',
    'Comma' => 'Pilkku',
    'Semi-colon' => 'Puolipiste',
    'Tab' => 'Sarkain',
    'Vertical bar' => 'Pystyviiva',
    'Double Quote' => 'Kaksoishevonkenkä',
    'Single Quote' => 'Yksinkertainen hevonkenkä',
    '%s attached a file to the task #%d' => '%s liitti tiedoston tehtävään #%d',
    'There is no column or swimlane activated in your project!' => 'Projektissasi ei ole aktivoitu sarakkeita tai kaistoja!',
    'Append filter (instead of replacement)' => 'Lisää suodatin (korvaamisen sijaan)',
    'Append/Replace' => 'Lisää/Korvaa',
    'Append' => 'Lisää',
    'Replace' => 'Korvaa',
    'Import' => 'Tuo',
    'Change sorting' => 'Muuta lajittelua',
    'Tasks Importation' => 'Tehtävien tuonti',
    'Delimiter' => 'Erotin',
    'Enclosure' => 'Sulkeet',
    'CSV File' => 'CSV-tiedosto',
    'Instructions' => 'Ohjeet',
    'Your file must use the predefined CSV format' => 'Tiedostosi on käytettävä es määriteltyä CSV-muotoa',
    'Your file must be encoded in UTF-8' => 'Tiedostosi on oltava koodattu UTF-8:lla',
    'The first row must be the header' => 'Ensimmäisen rivin on oltava otsikkorivi',
    'Duplicates are not verified for you' => 'Kopioita ei tarkisteta puolestasi',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Määräpäivän on käytettävä ISO-muotoa: VVVV-KK-PV',
    'Download CSV template' => 'Lataa CSV-mallitiedosto',
    'No external integration registered.' => 'Ei ulkoisia integraatioita rekisteröity.',
    'Duplicates are not imported' => 'Kopioita ei tuoda',
    'Usernames must be lowercase and unique' => 'Käyttäjänimien on oltava pienikirjaimisia ja yksilöllisiä',
    'Passwords will be encrypted if present' => 'Salasanat salataan, jos niitä on',
    '%s attached a new file to the task %s' => '%s liitti uuden tiedoston tehtävään %s',
    'Link type' => 'Linkin tyyppi',
    'Assign automatically a category based on a link' => 'Määritä automaattisesti luokka linkin perusteella',
    'BAM - Konvertible Mark' => 'BAM - Konvertibilna Marka',
    'Assignee Username' => 'Määrätyn käyttäjänimi',
    'Assignee Name' => 'Määrätyn nimi',
    'Groups' => 'Ryhmät',
    'Members of %s' => 'Ryhmän %s jäsenet',
    'New group' => 'Uusi ryhmä',
    'Group created successfully.' => 'Ryhmä luotiin onnistuneesti.',
    'Unable to create your group.' => 'Ryhmää ei voitu luoda.',
    'Edit group' => 'Muokkaa ryhmää',
    'Group updated successfully.' => 'Ryhmä päivitettiin onnistuneesti.',
    'Unable to update your group.' => 'Ryhmän päivittäminen epäonnistui.',
    'Add group member to "%s"' => 'Lisää ryhmän jäsen ryhmään "%s"',
    'Group member added successfully.' => 'Ryhmän jäsen lisättiin onnistuneesti.',
    'Unable to add group member.' => 'Ryhmän jäsentä ei voitu lisätä.',
    'Remove user from group "%s"' => 'Poista käyttäjä ryhmästä "%s"',
    'User removed successfully from this group.' => 'Käyttäjä poistettiin onnistuneesti tästä ryhmästä.',
    'Unable to remove this user from the group.' => 'Tämän käyttäjän poistaminen ryhmästä epäonnistui.',
    'Remove group' => 'Poista ryhmä',
    'Group removed successfully.' => 'Ryhmä poistettiin onnistuneesti.',
    'Unable to remove this group.' => 'Ryhmän poistaminen epäonnistui.',
    'Project Permissions' => 'Projektin käyttöoikeudet',
    'Manager' => 'Päällikkö',
    'Project Manager' => 'Projektipäällikkö',
    'Project Member' => 'Projektin jäsen',
    'Project Viewer' => 'Projektin katselija',
    'Your account is locked for %d minutes' => 'Tilisi on lukittu %d minuutiksi',
    'Invalid captcha' => 'Virheellinen captcha',
    'The name must be unique' => 'Nimen on oltava yksilöllinen',
    'View all groups' => 'Näytä kaikki ryhmät',
    'There is no user available.' => 'Käyttäjiä ei ole saatavilla.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Haluatko todella poistaa käyttäjän "%s" ryhmästä "%s"?',
    'There is no group.' => 'Ei ryhmiä.',
    'Add group member' => 'Lisää ryhmän jäsen',
    'Do you really want to remove this group: "%s"?' => 'Haluatko todella poistaa tämän ryhmän: "%s"?',
    'There is no user in this group.' => 'Ei käyttäjiä tässä ryhmässä.',
    'Permissions' => 'Käyttöoikeudet',
    'Allowed Users' => 'Sallitut käyttäjät',
    'No specific user has been allowed.' => 'Mitään tiettyä käyttäjää ei ole sallittu.',
    'Role' => 'Rooli',
    'Enter user name...' => 'Syötä käyttäjänimi...',
    'Allowed Groups' => 'Sallitut ryhmät',
    'No group has been allowed.' => 'Mitään ryhmää ei ole sallittu.',
    'Group' => 'Ryhmä',
    'Group Name' => 'Ryhmän nimi',
    'Enter group name...' => 'Syötä ryhmän nimi...',
    'Role:' => 'Rooli:',
    'Project members' => 'Projektin jäsenet',
    '%s mentioned you in the task #%d' => '%s mainitsi sinut tehtävässä #%d',
    '%s mentioned you in a comment on the task #%d' => '%s mainitsi sinut kommentissa tehtävässä #%d',
    'You were mentioned in the task #%d' => 'Sinut mainittiin tehtävässä #%d',
    'You were mentioned in a comment on the task #%d' => 'Sinut mainittiin kommentissa tehtävässä #%d',
    'Estimated hours: ' => 'Arvioidut tunnit:',
    'Actual hours: ' => 'Todelliset tunnit:',
    'Hours Spent' => 'Käytetyt tunnit',
    'Hours Estimated' => 'Arvioidut tunnit',
    'Estimated Time' => 'Arvioitu aika',
    'Actual Time' => 'Todellinen aika',
    'Estimated vs actual time' => 'Arvioitu vs todellinen aika',
    'RUB - Russian Ruble' => 'RUB - Venäjän rupla',
    'Assign the task to the person who does the action when the column is changed' => 'Määritä tehtävä henkilölle, joka suorittaa toimenpiteen saraketta vaihdettaessa',
    'Close a task in a specific column' => 'Sulje tehtävä tietyssä sarakkeessa',
    'Time-based One-time Password Algorithm' => 'Aikaan perustuva kertaluonteinen salasana-algoritmi',
    'Two-Factor Provider: ' => 'Kaksivaiheisen tunnistautumisen tarjoaja:',
    'Disable two-factor authentication' => 'Poista kaksivaiheinen tunnistautuminen käytöstä',
    'Enable two-factor authentication' => 'Ota kaksivaiheinen tunnistautuminen käyttöön',
    'There is no integration registered at the moment.' => 'Tällä hetkellä ei ole rekisteröity integraatioita.',
    'Password Reset for Kanboard' => 'Kanboardin salasanan palautus',
    'Forgot password?' => 'Unohtuiko salasana?',
    'Enable "Forget Password"' => 'Ota "Unohdin salasanan" käyttöön',
    'Password Reset' => 'Salasanan palautus',
    'New password' => 'Uusi salasana',
    'Change Password' => 'Vaihda salasana',
    'To reset your password click on this link:' => 'Palauttaaksesi salasanasi klikkaa tätä linkkiä:',
    'Last Password Reset' => 'Viimeisin salasanan palautus',
    'The password has never been reinitialized.' => 'Salasanaa ei ole koskaan alustettu uudelleen.',
    'Creation' => 'Luonti',
    'Expiration' => 'Vanheneminen',
    'Password reset history' => 'Salasanan palautushistoria',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Kaikki sarakkeen "%s" ja kaistan "%s" tehtävät on suljettu onnistuneesti.',
    'Do you really want to close all tasks of this column?' => 'Haluatko todella sulkea kaikki tämän sarakkeen tehtävät?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d tehtävä(t) sarakkeessa "%s" ja kaistalla "%s" suljetaan.',
    'Close all tasks in this column and this swimlane' => 'Sulje kaikki tehtävät tässä sarakkeessa ja tällä kaistalla',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Yksikään lisäosa ei ole rekisteröinyt projektin ilmoitusmenetelmää. Voit edelleen määrittää yksittäisiä ilmoituksia käyttäjäprofiilissasi.',
    'My dashboard' => 'Oma hallintapaneelini',
    'My profile' => 'Oma profiilini',
    'Project owner: ' => 'Projektin omistaja:',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Projektin tunniste on valinnainen ja sen on oltava aakkosnumeerinen, esimerkiksi: MYPROJECT.',
    'Project owner' => 'Projektin omistaja',
    'Personal projects do not have users and groups management.' => 'Henkilökohtaisissa projekteissa ei ole käyttäjä- ja ryhmähallintaa.',
    'There is no project member.' => 'Ei projektin jäseniä.',
    'Priority' => 'Prioriteetti',
    'Task priority' => 'Tehtävän prioriteetti',
    'General' => 'Yleiset',
    'Dates' => 'Päivämäärät',
    'Default priority' => 'Oletusprioriteetti',
    'Lowest priority' => 'Alin prioriteetti',
    'Highest priority' => 'Korkein prioriteetti',
    'Close a task when there is no activity' => 'Sulje tehtävä, kun siinä ei ole toimintaa',
    'Duration in days' => 'Kesto päivinä',
    'Send email when there is no activity on a task' => 'Lähetä sähköposti, kun tehtävässä ei ole toimintaa',
    'Unable to fetch link information.' => 'Linkin tietojen haku epäonnistui.',
    'Daily background job for tasks' => 'Päivittäinen taustatyö tehtäville',
    'Auto' => 'Auto',
    'Related' => 'Liittyvät',
    'Attachment' => 'Liite',
    'Web Link' => 'Web-linkki',
    'External links' => 'Ulkoiset linkit',
    'Add external link' => 'Lisää ulkoinen linkki',
    'Type' => 'Tyyppi',
    'Dependency' => 'Riippuvuus',
    'Add internal link' => 'Lisää sisäinen linkki',
    'Add a new external link' => 'Lisää uusi ulkoinen linkki',
    'Edit external link' => 'Muokkaa ulkoista linkkiä',
    'External link' => 'Ulkoinen linkki',
    'Copy and paste your link here...' => 'Kopioi ja liitä linkkisi tähän...',
    'URL' => 'URL',
    'Internal links' => 'Sisäiset linkit',
    'Assign to me' => 'Määritä minulle',
    'Me' => 'Minä',
    'Do not duplicate anything' => 'Älä kopioi mitään',
    'Projects management' => 'Projektien hallinta',
    'Users management' => 'Käyttäjien hallinta',
    'Groups management' => 'Ryhmien hallinta',
    'Create from another project' => 'Luo toisesta projektista',
    'open' => 'avoinna',
    'closed' => 'suljettu',
    'Priority:' => 'Prioriteetti:',
    'Reference:' => 'Viite:',
    'Complexity:' => 'Monimutkaisuus:',
    'Swimlane:' => 'Kaista:',
    'Column:' => 'Sarake:',
    'Position:' => 'Sijainti:',
    'Creator:' => 'Luonut:',
    'Time estimated:' => 'Arvioitu aika:',
    '%s hours' => '%s tuntia',
    'Time spent:' => 'Käytetty aika:',
    'Created:' => 'Luotu:',
    'Modified:' => 'Muokattu:',
    'Completed:' => 'Valmistunut:',
    'Started:' => 'Aloitettu:',
    'Moved:' => 'Siirretty:',
    'Task #%d' => 'Tehtävä #%d',
    'Time format' => 'Ajan muoto',
    'Start date: ' => 'Aloituspäivämäärä:',
    'End date: ' => 'Lopetuspäivämäärä:',
    'New due date: ' => 'Uusi määräpäivä:',
    'Start date changed: ' => 'Aloituspäivämäärä muutettu:',
    'Disable personal projects' => 'Poista henkilökohtaiset projektit käytöstä',
    'Do you really want to remove this custom filter: "%s"?' => 'Haluatko todella poistaa tämän mukautetun suodattimen: "%s"?',
    'Remove a custom filter' => 'Poista mukautettu suodatin',
    'User activated successfully.' => 'Käyttäjä aktivoitu onnistuneesti.',
    'Unable to enable this user.' => 'Tämän käyttäjän aktivointi epäonnistui.',
    'User disabled successfully.' => 'Käyttäjä poistettu käytöstä onnistuneesti.',
    'Unable to disable this user.' => 'Tämän käyttäjän käytöstä poistaminen epäonnistui.',
    'All files have been uploaded successfully.' => 'Kaikki tiedostot on ladattu onnistuneesti.',
    'The maximum allowed file size is %sB.' => 'Suurin sallittu tiedostokoko on %sB.',
    'Drag and drop your files here' => 'Vedä ja pudota tiedostosi tähän',
    'choose files' => 'valitse tiedostot',
    'View profile' => 'Näytä profiili',
    'Two Factor' => 'Kaksivaiheinen',
    'Disable user' => 'Poista käyttäjä käytöstä',
    'Do you really want to disable this user: "%s"?' => 'Haluatko todella poistaa tämän käyttäjän käytöstä: "%s"?',
    'Enable user' => 'Ota käyttäjä käyttöön',
    'Do you really want to enable this user: "%s"?' => 'Haluatko todella ottaa tämän käyttäjän käyttöön: "%s"?',
    'Download' => 'Lataa',
    'Uploaded: %s' => 'Ladattu: %s',
    'Size: %s' => 'Koko: %s',
    'Uploaded by %s' => 'Ladannut %s',
    'Filename' => 'Tiedostonimi',
    'Size' => 'Koko',
    'Column created successfully.' => 'Sarake luotiin onnistuneesti.',
    'Another column with the same name exists in the project' => 'Projektissa on jo toinen sarake samalla nimellä',
    'Default filters' => 'Oletussuodattimet',
    'Your board doesn\'t have any columns!' => 'Taulussasi ei ole yhtään saraketta!',
    'Change column position' => 'Muuta sarakkeen sijaintia',
    'Switch to the project overview' => 'Vaihda projektin yleiskatsaukseen',
    'User filters' => 'Käyttäjäsuodattimet',
    'Category filters' => 'Luokkusuodattimet',
    'Upload a file' => 'Lataa tiedosto',
    'View file' => 'Näytä tiedosto',
    'Last activity' => 'Viimeisin aktiviteetti',
    'Change subtask position' => 'Muuta alitehtävän sijaintia',
    'This value must be greater than %d' => 'Tämän arvon on oltava suurempi kuin %d',
    'Another swimlane with the same name exists in the project' => 'Projektissa on jo toinen kaista samalla nimellä',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Esimerkki: https://example.kanboard.org/ (käytetään absoluuttisten URL-osoitteiden luomiseen)',
    'Actions duplicated successfully.' => 'Toiminnot kopioitu onnistuneesti.',
    'Unable to duplicate actions.' => 'Toimintoja ei voitu kopioida.',
    'Add a new action' => 'Lisää uusi toiminto',
    'Import from another project' => 'Tuo toisesta projektista',
    'There is no action at the moment.' => 'Tällä hetkellä ei ole toimintoja.',
    'Import actions from another project' => 'Tuo toiminnot toisesta projektista',
    'There is no available project.' => 'Ei käytettävissä olevia projekteja.',
    'Local File' => 'Paikallinen tiedosto',
    'Configuration' => 'Konfiguraatio',
    'PHP version:' => 'PHP-versio:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Käyttöjärjestelmän versio:',
    'Database version:' => 'Tietokannan versio:',
    'Browser:' => 'Selain:',
    'Task view' => 'Tehtävänäkymä',
    'Edit task' => 'Muokkaa tehtävää',
    'Edit description' => 'Muokkaa kuvausta',
    'New internal link' => 'Uusi sisäinen linkki',
    'Display list of keyboard shortcuts' => 'Näytä lista pikanäppäimistä',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Lataa avatar-kuvani',
    'Remove my image' => 'Poista kuvani',
    'The OAuth2 state parameter is invalid' => 'OAuth2 state -parametri on virheellinen',
    'User not found.' => 'Käyttäjää ei löydy.',
    'Search in activity stream' => 'Hae aktiviteettivirrasta',
    'My activities' => 'Omat aktiviteetit',
    'Activity until yesterday' => 'Aktiviteetti eiliseen asti',
    'Activity until today' => 'Aktiviteetti tähän päivään asti',
    'Search by creator: ' => 'Hae luojan mukaan:',
    'Search by creation date: ' => 'Hae luontipäivämäärän mukaan:',
    'Search by task status: ' => 'Hae tehtävän tilan mukaan:',
    'Search by task title: ' => 'Hae tehtävän otsikon mukaan:',
    'Activity stream search' => 'Aktiviteettivirran haku',
    'Projects where "%s" is manager' => 'Projektit, joissa "%s" on päällikkö',
    'Projects where "%s" is member' => 'Projektit, joissa "%s" on jäsen',
    'Open tasks assigned to "%s"' => 'Avoimet tehtävät, jotka on määritetty käyttäjälle "%s"',
    'Closed tasks assigned to "%s"' => 'Suljetut tehtävät, jotka on määritetty käyttäjälle "%s"',
    'Assign automatically a color based on a priority' => 'Määritä automaattisesti väri prioriteetin perusteella',
    'Overdue tasks for the project(s) "%s"' => 'Myöhässä olevat tehtävät projektille/projekteille "%s"',
    'Upload files' => 'Lataa tiedostoja',
    'Installed Plugins' => 'Asennetut lisäosat',
    'Plugin Directory' => 'Lisäosahakemisto',
    'Plugin installed successfully.' => 'Lisäosa asennettiin onnistuneesti.',
    'Plugin updated successfully.' => 'Lisäosa päivitettiin onnistuneesti.',
    'Plugin removed successfully.' => 'Lisäosa poistettiin onnistuneesti.',
    'Subtask converted to task successfully.' => 'Alitehtävä muunnettiin tehtäväksi onnistuneesti.',
    'Unable to convert the subtask.' => 'Alitehtävää ei voitu muuntaa.',
    'Unable to extract plugin archive.' => 'Lisäosan arkistoa ei voitu purkaa.',
    'Plugin not found.' => 'Lisäosaa ei löydy.',
    'You don\'t have the permission to remove this plugin.' => 'Sinulla ei ole oikeutta poistaa tätä lisäosaa.',
    'Unable to download plugin archive.' => 'Lisäosan arkiston lataaminen epäonnistui.',
    'Unable to write temporary file for plugin.' => 'Lisäosan väliaikaista tiedostoa ei voitu kirjoittaa.',
    'Unable to open plugin archive.' => 'Lisäosan arkistoa ei voitu avata.',
    'There is no file in the plugin archive.' => 'Lisäosan arkistossa ei ole tiedostoa.',
    'Create tasks in bulk' => 'Luo tehtäviä joukkona',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Kanboard-instanssiasi ei ole määritetty asentamaan lisäosia käyttöliittymän kautta.',
    'There is no plugin available.' => 'Lisäosia ei ole saatavilla.',
    'Install' => 'Asenna',
    'Update' => 'Päivitä',
    'Up to date' => 'Ajantasalla',
    'Not available' => 'Ei saatavilla',
    'Remove plugin' => 'Poista lisäosa',
    'Do you really want to remove this plugin: "%s"?' => 'Haluatko todella poistaa tämän lisäosan: "%s"?',
    'Uninstall' => 'Poista asennus',
    'Listing' => 'Listaus',
    'Metadata' => 'Metatiedot',
    'Manage projects' => 'Hallinnoi projekteja',
    'Convert to task' => 'Muunna tehtäväksi',
    'Convert sub-task to task' => 'Muunna alitehtävä tehtäväksi',
    'Do you really want to convert this sub-task to a task?' => 'Haluatko todella muuntaa tämän alitehtävän tehtäväksi?',
    'My task title' => 'Oman tehtävän otsikko',
    'Enter one task by line.' => 'Syötä yksi tehtävä riviä kohden.',
    'Number of failed login:' => 'Epäonnistuneiden kirjautumisten määrä:',
    'Account locked until:' => 'Tili lukittu:',
    'Email settings' => 'Sähköpostiasetukset',
    'Email sender address' => 'Sähköpostin lähettäjän osoite',
    'Email transport' => 'Sähköpostin siirto',
    'Webhook token' => 'Webhook-tunnus',
    'Project tags management' => 'Projektin tunnisteiden hallinta',
    'Tag created successfully.' => 'Tunniste luotiin onnistuneesti.',
    'Unable to create this tag.' => 'Tätä tunnistetta ei voitu luoda.',
    'Tag updated successfully.' => 'Tunniste päivitettiin onnistuneesti.',
    'Unable to update this tag.' => 'Tätä tunnistetta ei voitu päivittää.',
    'Tag removed successfully.' => 'Tunniste poistettiin onnistuneesti.',
    'Unable to remove this tag.' => 'Tämän tunnisteen poistaminen epäonnistui.',
    'Global tags management' => 'Globaalien tunnisteiden hallinta',
    'Tags' => 'Tunnisteet',
    'Tags management' => 'Tunnisteiden hallinta',
    'Add new tag' => 'Lisää uusi tunniste',
    'Edit a tag' => 'Muokkaa tunnistetta',
    'Project tags' => 'Projektin tunnisteet',
    'There is no specific tag for this project at the moment.' => 'Tällä hetkellä projektille ei ole erityistä tunnistetta.',
    'Tag' => 'Tunniste',
    'Remove a tag' => 'Poista tunniste',
    'Do you really want to remove this tag: "%s"?' => 'Haluatko todella poistaa tämän tunnisteen: "%s"?',
    'Global tags' => 'Globaalit tunnisteet',
    'There is no global tag at the moment.' => 'Tällä hetkellä ei ole globaalia tunnistetta.',
    'This field cannot be empty' => 'Tämä kenttä ei saa olla tyhjä',
    'Close a task when there is no activity in a specific column' => 'Sulje tehtävä, kun tietyssä sarakkeessa ei ole toimintaa',
    '%s removed a subtask for the task #%d' => '%s poisti alitehtävän tehtävälle #%d',
    '%s removed a comment on the task #%d' => '%s poisti kommentin tehtävästä #%d',
    'Comment removed on task #%d' => 'Kommentti poistettu tehtävästä #%d',
    'Subtask removed on task #%d' => 'Alitehtävä poistettu tehtävästä #%d',
    'Hide tasks in this column in the dashboard' => 'Piilota tehtävät tässä sarakkeessa hallintapaneelissa',
    '%s removed a comment on the task %s' => '%s poisti kommentin tehtävästä %s',
    '%s removed a subtask for the task %s' => '%s poisti alitehtävän tehtävästä %s',
    'Comment removed' => 'Kommentti poistettu',
    'Subtask removed' => 'Alitehtävä poistettu',
    '%s set a new internal link for the task #%d' => '%s asetti uuden sisäisen linkin tehtävälle #%d',
    '%s removed an internal link for the task #%d' => '%s poisti sisäisen linkin tehtävälle #%d',
    'A new internal link for the task #%d has been defined' => 'Uusi sisäinen linkki tehtävälle #%d on määritetty',
    'Internal link removed for the task #%d' => 'Sisäinen linkki poistettu tehtävälle #%d',
    '%s set a new internal link for the task %s' => '%s asetti uuden sisäisen linkin tehtävälle %s',
    '%s removed an internal link for the task %s' => '%s poisti sisäisen linkin tehtävälle %s',
    'Automatically set the due date on task creation' => 'Aseta automaattisesti määräpäivä tehtävän luonnin yhteydessä',
    'Move the task to another column when closed' => 'Siirrä tehtävä toiseen sarakkeeseen, kun se suljetaan',
    'Move the task to another column when not moved during a given period' => 'Siirrä tehtävä toiseen sarakkeeseen, kun sitä ei ole siirretty tietyn ajanjakson aikana',
    'Dashboard for %s' => 'Hallintapaneeli käyttäjälle %s',
    'Tasks overview for %s' => 'Tehtävien yleiskatsaus käyttäjälle %s',
    'Subtasks overview for %s' => 'Alitehtävien yleiskatsaus käyttäjälle %s',
    'Projects overview for %s' => 'Projektien yleiskatsaus käyttäjälle %s',
    'Activity stream for %s' => 'Aktiviteettivirta käyttäjälle %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Määritä väri, kun tehtävä siirretään tiettyyn kaistaan',
    'Assign a priority when the task is moved to a specific swimlane' => 'Määritä prioriteetti, kun tehtävä siirretään tiettyyn kaistaan',
    'User unlocked successfully.' => 'Käyttäjä avattiin onnistuneesti.',
    'Unable to unlock the user.' => 'Käyttäjää ei voitu avata.',
    'Move a task to another swimlane' => 'Siirrä tehtävä toiseen kaistaan',
    'Creator Name' => 'Luojan nimi',
    'Time spent and estimated' => 'Käytetty ja arvioitu aika',
    'Move position' => 'Siirrä sijaintia',
    'Move task to another position on the board' => 'Siirrä tehtävä toiseen sijaintiin taululla',
    'Insert before this task' => 'Lisää ennen tätä tehtävää',
    'Insert after this task' => 'Lisää tämän tehtävän jälkeen',
    'Unlock this user' => 'Avaa tämä käyttäjä',
    'Custom Project Roles' => 'Mukautetut projektiroolit',
    'Add a new custom role' => 'Lisää uusi mukautettu rooli',
    'Restrictions for the role "%s"' => 'Rajoitukset roolille "%s"',
    'Add a new project restriction' => 'Lisää uusi projektirajoitus',
    'Add a new drag and drop restriction' => 'Lisää uusi vedä ja pudota -rajoitus',
    'Add a new column restriction' => 'Lisää uusi sarakkeiden rajoitus',
    'Edit this role' => 'Muokkaa tätä roolia',
    'Remove this role' => 'Poista tämä rooli',
    'There is no restriction for this role.' => 'Tälle roolille ei ole rajoituksia.',
    'Only moving task between those columns is permitted' => 'Tehtävän siirtäminen on sallittua vain näiden sarakkeiden välillä',
    'Close a task in a specific column when not moved during a given period' => 'Sulje tehtävä tietyssä sarakkeessa, kun sitä ei ole siirretty tietyn ajanjakson aikana',
    'Edit columns' => 'Muokkaa sarakkeita',
    'The column restriction has been created successfully.' => 'Sarakkeiden rajoitus luotiin onnistuneesti.',
    'Unable to create this column restriction.' => 'Tätä sarakkeiden rajoitusta ei voitu luoda.',
    'Column restriction removed successfully.' => 'Sarakkeiden rajoitus poistettiin onnistuneesti.',
    'Unable to remove this restriction.' => 'Tämän rajoituksen poistaminen epäonnistui.',
    'Your custom project role has been created successfully.' => 'Mukautettu projektiroolisi luotiin onnistuneesti.',
    'Unable to create custom project role.' => 'Mukautettua projektiroolia ei voitu luoda.',
    'Your custom project role has been updated successfully.' => 'Mukautettu projektiroolisi on päivitetty onnistuneesti.',
    'Unable to update custom project role.' => 'Mukautetun projektiroolin päivittäminen epäonnistui.',
    'Custom project role removed successfully.' => 'Mukautettu projektirooli poistettiin onnistuneesti.',
    'Unable to remove this project role.' => 'Tämän projektiroolin poistaminen epäonnistui.',
    'The project restriction has been created successfully.' => 'Projektirajoitus luotiin onnistuneesti.',
    'Unable to create this project restriction.' => 'Tätä projektirajoitusta ei voitu luoda.',
    'Project restriction removed successfully.' => 'Projektirajoitus poistettiin onnistuneesti.',
    'You cannot create tasks in this column.' => 'Et voi luoda tehtäviä tähän sarakkeeseen.',
    'Task creation is permitted for this column' => 'Tehtävien luominen on sallittu tähän sarakkeeseen',
    'Closing or opening a task is permitted for this column' => 'Tehtävän sulkeminen tai avaaminen on sallittu tähän sarakkeeseen',
    'Task creation is blocked for this column' => 'Tehtävien luominen on estetty tähän sarakkeeseen',
    'Closing or opening a task is blocked for this column' => 'Tehtävän sulkeminen tai avaaminen on estetty tähän sarakkeeseen',
    'Task creation is not permitted' => 'Tehtävien luominen ei ole sallittua',
    'Closing or opening a task is not permitted' => 'Tehtävän sulkeminen tai avaaminen ei ole sallittua',
    'New drag and drop restriction for the role "%s"' => 'Uusi vedä ja pudota -rajoitus roolille "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Tähän rooliin kuuluvat henkilöt voivat siirtää tehtäviä vain lähde- ja kohdesarakkeen välillä.',
    'Remove a column restriction' => 'Poista sarakkeiden rajoitus',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Haluatko todella poistaa tämän sarakkeiden rajoituksen: "%s" to "%s"?',
    'New column restriction for the role "%s"' => 'Uusi sarakkeiden rajoitus roolille "%s"',
    'Rule' => 'Sääntö',
    'Do you really want to remove this column restriction?' => 'Haluatko todella poistaa tämän sarakkeiden rajoituksen?',
    'Custom roles' => 'Mukautetut roolit',
    'New custom project role' => 'Uusi mukautettu projektirooli',
    'Edit custom project role' => 'Muokkaa mukautettua projektiroolia',
    'Remove a custom role' => 'Poista mukautettu rooli',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Haluatko todella poistaa tämän mukautetun roolin: "%s"? Kaikista tähän rooliin määritetyistä henkilöistä tulee projektin jäseniä.',
    'There is no custom role for this project.' => 'Tälle projektille ei ole mukautettua roolia.',
    'New project restriction for the role "%s"' => 'Uusi projektirajoitus roolille "%s"',
    'Restriction' => 'Rajoitus',
    'Remove a project restriction' => 'Poista projektirajoitus',
    'Do you really want to remove this project restriction: "%s"?' => 'Haluatko todella poistaa tämän projektirajoituksen: "%s"?',
    'Duplicate to multiple projects' => 'Kopioi useisiin projekteihin',
    'This field is required' => 'Tämä kenttä on pakollinen',
    'Moving a task is not permitted' => 'Tehtävän siirtäminen ei ole sallittua',
    'This value must be in the range %d to %d' => 'Tämän arvon on oltava välillä %d–%d',
    'You are not allowed to move this task.' => 'Sinulla ei ole oikeutta siirtää tätä tehtävää.',
    'API User Access' => 'API-käyttäjän käyttöoikeus',
    'Preview' => 'Esikatselu',
    'Write' => 'Kirjoita',
    'Write your text in Markdown' => 'Kirjoita teksti Markdown-muodossa',
    'No personal API access token registered.' => 'Henkilökohtaista API-käyttöoikeustunnusta ei ole rekisteröity.',
    'Your personal API access token is "%s"' => 'Henkilökohtainen API-käyttöoikeustunnuksesi on "%s"',
    'Remove your token' => 'Poista tunnuksesi',
    'Generate a new token' => 'Luo uusi tunnus',
    'Showing %d-%d of %d' => 'Näytetään %d–%d / %d',
    'Outgoing Emails' => 'Lähtevät sähköpostit',
    'Add or change currency rate' => 'Lisää tai muuta valuuttakurssi',
    'Reference currency: %s' => 'Vertailuvaluutta: %s',
    'Add custom filters' => 'Lisää mukautettuja suodattimia',
    'Export' => 'Vie',
    'Add link label' => 'Lisää linkin selite',
    'Incompatible Plugins' => 'Yhteensopimattomat lisäosat',
    'Compatibility' => 'Yhteensopivuus',
    'Permissions and ownership' => 'Oikeudet ja omistajuus',
    'Priorities' => 'Prioriteetit',
    'Close this window' => 'Sulje tämä ikkuna',
    'Unable to upload this file.' => 'Tiedoston lataaminen epäonnistui.',
    'Import tasks' => 'Tuo tehtäviä',
    'Choose a project' => 'Valitse projekti',
    'Profile' => 'Profiili',
    'Application role' => 'Sovelluksen rooli',
    '%d invitations were sent.' => '%d kutsua lähetettiin.',
    '%d invitation was sent.' => '%d kutsu lähetettiin.',
    'Unable to create this user.' => 'Tämän käyttäjän luominen epäonnistui.',
    'Kanboard Invitation' => 'Kanboard-kutsu',
    'Visible on dashboard' => 'Näkyvissä hallintapaneelissa',
    'Created at:' => 'Luotu:',
    'Updated at:' => 'Päivitetty:',
    'There is no custom filter.' => 'Mukautettuja suodattimia ei ole.',
    'New User' => 'Uusi käyttäjä',
    'Authentication' => 'Tunnistautuminen',
    'If checked, this user will use a third-party system for authentication.' => 'Jos valittu, tämä käyttäjä käyttää kolmannen osapuolen järjestelmää tunnistautumiseen.',
    'The password is necessary only for local users.' => 'Salasana on tarpeen vain paikallisille käyttäjille.',
    'You have been invited to register on Kanboard.' => 'Sinut on kutsuttu rekisteröitymään Kanboardiin.',
    'Click here to join your team' => 'Klikkaa tästä liittyäksesi tiimiisi',
    'Invite people' => 'Kutsu ihmisiä',
    'Emails' => 'Sähköpostit',
    'Enter one email address by line.' => 'Syötä yksi sähköpostiosoite riviä kohden.',
    'Add these people to this project' => 'Lisää nämä henkilöt tähän projektiin',
    'Add this person to this project' => 'Lisää tämä henkilö tähän projektiin',
    'Sign-up' => 'Rekisteröidy',
    'Credentials' => 'Tunnistetiedot',
    'New user' => 'Uusi käyttäjä',
    'This username is already taken' => 'Tämä käyttäjänimi on jo käytössä',
    'Your profile must have a valid email address.' => 'Profiilillasi on oltava kelvollinen sähköpostiosoite.',
    'TRL - Turkish Lira' => 'TRL - Turkin liira',
    'The project email is optional and could be used by several plugins.' => 'Projektin sähköposti on valinnainen ja sitä voivat käyttää useat lisäosat.',
    'The project email must be unique across all projects' => 'Projektin sähköpostin on oltava yksilöllinen kaikissa projekteissa',
    'The email configuration has been disabled by the administrator.' => 'Sähköpostiasetukset on poistettu käytöstä järjestelmänvalvojan toimesta.',
    'Close this project' => 'Sulje tämä projekti',
    'Open this project' => 'Avaa tämä projekti',
    'Close a project' => 'Sulje projekti',
    'Do you really want to close this project: "%s"?' => 'Haluatko todella sulkea tämän projektin: "%s"?',
    'Reopen a project' => 'Avaa projekti uudelleen',
    'Do you really want to reopen this project: "%s"?' => 'Haluatko todella avata tämän projektin uudelleen: "%s"?',
    'This project is open' => 'Tämä projekti on avoinna',
    'This project is closed' => 'Tämä projekti on suljettu',
    'Unable to upload files, check the permissions of your data folder.' => 'Tiedostojen lataaminen epäonnistui, tarkista datakansion oikeudet.',
    'Another category with the same name exists in this project' => 'Projektissa on jo toinen luokka samalla nimellä',
    'Comment sent by email successfully.' => 'Kommentti lähetettiin sähköpostitse onnistuneesti.',
    'Sent by email to "%s" (%s)' => 'Lähetetty sähköpostitse osoitteeseen "%s" (%s)',
    'Unable to read uploaded file.' => 'Ladattua tiedostoa ei voitu lukea.',
    'Database uploaded successfully.' => 'Tietokanta ladattiin onnistuneesti.',
    'Task sent by email successfully.' => 'Tehtävä lähetettiin sähköpostitse onnistuneesti.',
    'There is no category in this project.' => 'Projektissa ei ole luokkia.',
    'Send by email' => 'Lähetä sähköpostitse',
    'Create and send a comment by email' => 'Luo ja lähetä kommentti sähköpostitse',
    'Subject' => 'Aihe',
    'Upload the database' => 'Lataa tietokanta',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Voit ladata aiemmin ladatun Sqlite-tietokannan (Gzip-muodossa).',
    'Database file' => 'Tietokantatiedosto',
    'Upload' => 'Lataa',
    'Your project must have at least one active swimlane.' => 'Projektissasi on oltava vähintään yksi aktiivinen kaista.',
    'Project: %s' => 'Projekti: %s',
    'Automatic action not found: "%s"' => 'Automaattista toimintoa ei löytynyt: "%s"',
    '%d projects' => '%d projektia',
    '%d project' => '%d projekti',
    'There is no project.' => 'Projekteja ei ole.',
    'Sort' => 'Järjestys',
    'Project ID' => 'Projektin ID',
    'Project name' => 'Projektin nimi',
    'Public' => 'Julkinen',
    'Personal' => 'Henkilökohtainen',
    '%d tasks' => '%d tehtävää',
    '%d task' => '%d tehtävä',
    'Task ID' => 'Tehtävän ID',
    'Assign automatically a color when due date is expired' => 'Määritä automaattisesti väri, kun määräpäivä on ohitettu',
    'Total score in this column across all swimlanes' => 'Kokonaispistemäärä tässä sarakkeessa kaikilla kaistoilla',
    'HRK - Kuna' => 'HRK - Kroatian kuna',
    'ARS - Argentine Peso' => 'ARS - Argentiinan peso',
    'COP - Colombian Peso' => 'COP - Kolumbian peso',
    '%d groups' => '%d ryhmää',
    '%d group' => '%d ryhmä',
    'Group ID' => 'Ryhmän ID',
    'External ID' => 'Ulkoinen ID',
    '%d users' => '%d käyttäjää',
    '%d user' => '%d käyttäjä',
    'Hide subtasks' => 'Piilota alitehtävät',
    'Show subtasks' => 'Näytä alitehtävät',
    'Authentication Parameters' => 'Tunnistautumisparametrit',
    'API Access' => 'API-käyttöoikeus',
    'No users found.' => 'Käyttäjiä ei löytynyt.',
    'User ID' => 'Käyttäjän ID',
    'Notifications are activated' => 'Ilmoitukset ovat aktivoitu',
    'Notifications are disabled' => 'Ilmoitukset ovat poistettu käytöstä',
    'User disabled' => 'Käyttäjä poistettu käytöstä',
    '%d notifications' => '%d ilmoitusta',
    '%d notification' => '%d ilmoitus',
    'There is no external integration installed.' => 'Ulkoisia integraatioita ei ole asennettu.',
    'You are not allowed to update tasks assigned to someone else.' => 'Sinulla ei ole oikeutta päivittää muiden määrittämiä tehtäviä.',
    'You are not allowed to change the assignee.' => 'Sinulla ei ole oikeutta muuttaa määrättyä henkilöä.',
    'Task suppression is not permitted' => 'Tehtävien poistaminen ei ole sallittua',
    'Changing assignee is not permitted' => 'Määrätyn henkilön vaihtaminen ei ole sallittua',
    'Update only assigned tasks is permitted' => 'Vain määrättyjen tehtävien päivittäminen on sallittua',
    'Only for tasks assigned to the current user' => 'Vain tehtäviin, jotka on määritetty nykyiselle käyttäjälle',
    'My projects' => 'Omat projektini',
    'You are not a member of any project.' => 'Et ole minkään projektin jäsen.',
    'My subtasks' => 'Omat alitehtävät',
    '%d subtasks' => '%d alitehtävää',
    '%d subtask' => '%d alitehtävä',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Vain tehtävän siirtäminen näiden sarakkeiden välillä on sallittua nykyiselle käyttäjälle määritetyille tehtäville',
    '[DUPLICATE]' => '[KOPIO]',
    'DKK - Danish Krona' => 'DKK - Tanskan kruunu',
    'Remove user from group' => 'Poista käyttäjä ryhmästä',
    'Assign the task to its creator' => 'Määritä tehtävä sen luojalle',
    'This task was sent by email to "%s" with subject "%s".' => 'Tämä tehtävä lähetettiin sähköpostitse "%s" aiheella "%s".',
    'Predefined Email Subjects' => 'Ennalta määritellyt sähköpostin aiheet',
    'Write one subject by line.' => 'Kirjoita yksi aihe riviä kohden.',
    'Create another link' => 'Luo toinen linkki',
    'BRL - Brazilian Real' => 'BRL - Brasilian real',
    'Add a new Kanboard task' => 'Lisää uusi Kanboard-tehtävä',
    'Subtask not started' => 'Alitehtävä ei aloitettu',
    'Subtask currently in progress' => 'Alitehtävä on parhaillaan kesken',
    'Subtask completed' => 'Alitehtävä valmis',
    'Subtask added successfully.' => 'Alitehtävä lisättiin onnistuneesti.',
    '%d subtasks added successfully.' => '%d alitehtävää lisättiin onnistuneesti.',
    'Enter one subtask by line.' => 'Syötä yksi alitehtävä riviä kohden.',
    'Predefined Contents' => 'Ennalta määritellyt sisällöt',
    'Predefined contents' => 'Ennalta määritellyt sisällöt',
    'Predefined Task Description' => 'Ennalta määritelty tehtävän kuvaus',
    'Do you really want to remove this template? "%s"' => 'Haluatko todella poistaa tämän mallin? "%s"',
    'Add predefined task description' => 'Lisää ennalta määritelty tehtävän kuvaus',
    'Predefined Task Descriptions' => 'Ennalta määritellyt tehtävän kuvaukset',
    'Template created successfully.' => 'Malli luotiin onnistuneesti.',
    'Unable to create this template.' => 'Malliin luominen epäonnistui.',
    'Template updated successfully.' => 'Malli päivitettiin onnistuneesti.',
    'Unable to update this template.' => 'Mallin päivittäminen epäonnistui.',
    'Template removed successfully.' => 'Malli poistettiin onnistuneesti.',
    'Unable to remove this template.' => 'Mallin poistaminen epäonnistui.',
    'Template for the task description' => 'Malli tehtävän kuvaukseen',
    'The start date is greater than the end date' => 'Aloituspäivämäärä on suurempi kuin lopetuspäivämäärä',
    'Tags must be separated by a comma' => 'Tunnisteet on erotettava pilkulla',
    'Only the task title is required' => 'Vain tehtävän otsikko on pakollinen',
    'Creator Username' => 'Luojan käyttäjänimi',
    'Color Name' => 'Värin nimi',
    'Column Name' => 'Sarakkeen nimi',
    'Swimlane Name' => 'Kaistan nimi',
    'Time Estimated' => 'Arvioitu aika',
    'Time Spent' => 'Käytetty aika',
    'External Link' => 'Ulkoinen linkki',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Tämä ominaisuus mahdollistaa iCal-syötteen, RSS-syötteen ja julkisen taulunäkymän.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Pysäytä kaikkien alitehtävien ajastin, kun tehtävä siirretään toiseen sarakkeeseen',
    'Subtask Title' => 'Alitehtävän otsikko',
    'Add a subtask and activate the timer when moving a task to another column' => 'Lisää alitehtävä ja aktivoi ajastin, kun tehtävä siirretään toiseen sarakkeeseen',
    'days' => 'päivää',
    'minutes' => 'minuuttia',
    'seconds' => 'sekuntia',
    'Assign automatically a color when preset start date is reached' => 'Määritä automaattisesti väri, kun esiasetettu aloituspäivämäärä saavutetaan',
    'Move the task to another column once a predefined start date is reached' => 'Siirrä tehtävä toiseen sarakkeeseen, kun es määritelty aloituspäivämäärä on saavutettu',
    'This task is now linked to the task %s with the relation "%s"' => 'Tämä tehtävä on nyt linkitetty tehtävään %s suhteella "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Linkki tehtävään %s suhteella "%s" on poistettu',
    'Custom Filter:' => 'Mukautettu suodatin:',
    'Unable to find this group.' => 'Ryhmää ei löytynyt.',
    '%s moved the task #%d to the column "%s"' => '%s siirsi tehtävän #%d sarakkeeseen "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s siirsi tehtävän #%d sarakkeeseen "%s" paikkaan %d',
    '%s moved the task #%d to the swimlane "%s"' => '%s siirsi tehtävän #%d kaistaan "%s"',
    '%sh spent' => '%sh käytetty',
    '%sh estimated' => '%sh arvioitu',
    'Select All' => 'Valitse kaikki',
    'Unselect All' => 'Poista kaikkien valinta',
    'Apply action' => 'Suorita toiminto',
    'Move selected tasks to another column or swimlane' => 'Siirrä valitut tehtävät toiseen sarakkeeseen tai kaistaan',
    'Edit tasks in bulk' => 'Muokkaa tehtäviä joukkona',
    'Choose the properties that you would like to change for the selected tasks.' => 'Valitse ominaisuudet, jotka haluat muuttaa valituille tehtäville.',
    'Configure this project' => 'Määritä tämä projekti',
    'Start now' => 'Aloita nyt',
    '%s removed a file from the task #%d' => '%s poisti tiedoston tehtävästä #%d',
    'Attachment removed from task #%d: %s' => 'Liite poistettu tehtävästä #%d: %s',
    'No color' => 'Ei väriä',
    'Attachment removed "%s"' => 'Liite poistettu "%s"',
    '%s removed a file from the task %s' => '%s poisti tiedoston tehtävästä %s',
    'Move the task to another swimlane when assigned to a user' => 'Siirrä tehtävä toiseen kaistaan, kun se on määritetty käyttäjälle',
    'Destination swimlane' => 'Kohdekaista',
    'Assign a category when the task is moved to a specific swimlane' => 'Määritä luokka, kun tehtävä siirretään tiettyyn kaistaan',
    'Move the task to another swimlane when the category is changed' => 'Siirrä tehtävä toiseen kaistaan, kun luokkaa muutetaan',
    'Reorder this column by priority (ASC)' => 'Järjestä tämä sarake uudelleen prioriteetin mukaan (nouseva)',
    'Reorder this column by priority (DESC)' => 'Järjestä tämä sarake uudelleen prioriteetin mukaan (laskeva)',
    'Reorder this column by assignee and priority (ASC)' => 'Järjestä tämä sarake uudelleen määrätyn ja prioriteetin mukaan (nouseva)',
    'Reorder this column by assignee and priority (DESC)' => 'Järjestä tämä sarake uudelleen määrätyn ja prioriteetin mukaan (laskeva)',
    'Reorder this column by assignee (A-Z)' => 'Järjestä tämä sarake uudelleen määrätyn mukaan (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Järjestä tämä sarake uudelleen määrätyn mukaan (Z-A)',
    'Reorder this column by due date (ASC)' => 'Järjestä tämä sarake uudelleen määräpäivän mukaan (nouseva)',
    'Reorder this column by due date (DESC)' => 'Järjestä tämä sarake uudelleen määräpäivän mukaan (laskeva)',
    'Reorder this column by id (ASC)' => 'Järjestä tämä sarake uudelleen ID:n mukaan (nouseva)',
    'Reorder this column by id (DESC)' => 'Järjestä tämä sarake uudelleen ID:n mukaan (laskeva)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s siirsi tehtävän #%d "%s" projektiin "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Tehtävä #%d "%s" on siirretty projektiin "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Siirrä tehtävä toiseen sarakkeeseen, kun määräpäivään on vähemmän kuin tietty määrä päiviä',
    'Automatically update the start date when the task is moved away from a specific column' => 'Päivitä aloituspäivämäärä automaattisesti, kun tehtävä siirretään pois tietystä sarakkeesta',
    'HTTP Client:' => 'HTTP-asiakas:',
    'Assigned' => 'Määritetty',
    'Task limits apply to each swimlane individually' => 'Tehtävärajoitukset koskevat kutakin kaistaa erikseen',
    'Column task limits apply to each swimlane individually' => 'Sarakkeen tehtävärajoitukset koskevat kutakin kaistaa erikseen',
    'Column task limits are applied to each swimlane individually' => 'Sarakkeen tehtävärajoitukset koskevat kutakin kaistaa erikseen',
    'Column task limits are applied across swimlanes' => 'Sarakkeen tehtävärajoitukset koskevat kaikkia kaistoja',
    'Task limit: ' => 'Tehtävärajoitus:',
    'Change to global tag' => 'Vaihda globaaliksi tunnisteeksi',
    'Do you really want to make the tag "%s" global?' => 'Haluatko todella tehdä tunnisteesta "%s" globaalin?',
    'Enable global tags for this project' => 'Ota globaalit tunnisteet käyttöön tässä projektissa',
    'Group membership(s):' => 'Ryhmäjäsenyys (jäsenyydet):',
    '%s is a member of the following group(s): %s' => '%s on jäsen seuraavissa ryhmissä: %s',
    '%d/%d group(s) shown' => '%d/%d ryhmä(t) näytetty',
    'Subtask creation or modification' => 'Alitehtävän luominen tai muokkaaminen',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Määritä tehtävä tietylle käyttäjälle, kun tehtävä siirretään tiettyyn kaistaan',
    'Comment' => 'Kommentti',
    'Collapse vertically' => 'Kutista pystysuunnassa',
    'Expand vertically' => 'Laajenna pystysuunnassa',
    'MXN - Mexican Peso' => 'MXN - Meksikon peso',
    'Estimated vs actual time per column' => 'Arvioitu vs. todellinen aika saraketta kohden',
    'HUF - Hungarian Forint' => 'HUF - Unkarin forintti',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Sinun on valittava tiedosto ladattavaksi avatariksesi!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Lataamasi tiedosto ei ole kelvollinen kuva! (Vain *.gif, *.jpg, *.jpeg ja *.png on sallittu!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Aseta automaattisesti määräpäivä, kun tehtävä siirretään pois tietystä sarakkeesta',
    'No other projects found.' => 'Muita projekteja ei löytynyt.',
    'Tasks copied successfully.' => 'Tehtävät kopioitu onnistuneesti.',
    'Unable to copy tasks.' => 'Tehtäviä ei voitu kopioida.',
    'Theme' => 'Teema',
    'Theme:' => 'Teema:',
    'Light theme' => 'Vaalea teema',
    'Dark theme' => 'Tumma teema',
    'Automatic theme - Sync with system' => 'Automaattinen teema - Synkronoi järjestelmän kanssa',
    'Application managers or more' => 'Sovelluksen hallitsijat tai enemmän',
    'Administrators' => 'Ylläpitäjät',
    'Visibility:' => 'Näkyvyys:',
    'Standard users' => 'Standardikäyttäjät',
    'Visibility is required' => 'Näkyvyys on pakollinen',
    'The visibility should be an app role' => 'Näkyvyyden tulisi olla sovellusrooli',
    'Reply' => 'Vastaa',
    '%s wrote: ' => '%s kirjoitti:',
    'Number of visible tasks in this column and swimlane' => 'Tässä sarakkeessa ja kaistassa näkyvien tehtävien määrä',
    'Number of tasks in this swimlane' => 'Tehtävien määrä tässä kaistassa',
    'Unable to find another subtask in progress, you can close this window.' => 'Toista kesken olevaa alitehtävää ei löytynyt, voit sulkea tämän ikkunan.',
    'This theme is invalid' => 'Tämä teema on virheellinen',
    'This role is invalid' => 'Tämä rooli on virheellinen',
    'This timezone is invalid' => 'Tämä aikavyöhyke on virheellinen',
    'This language is invalid' => 'Tämä kieli on virheellinen',
    'This URL is invalid' => 'Tämä URL on virheellinen',
    'Date format invalid' => 'Päivämäärämuoto virheellinen',
    'Time format invalid' => 'Ajan muoto virheellinen',
    'Invalid Mail transport' => 'Virheellinen sähköpostin siirto',
    'Color invalid' => 'Väri virheellinen',
    'This value must be greater or equal to %d' => 'Tämän arvon on oltava suurempi tai yhtä suuri kuin %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Lisää BOM tiedoston alkuun (vaaditaan Microsoft Excelille)',
    'Just add these tag(s)' => 'Lisää vain nämä tunnisteet',
    'Remove internal link(s)' => 'Poista sisäinen linkki/linkit',
    'Import tasks from another project' => 'Tuo tehtäviä toisesta projektista',
    'Select the project to copy tasks from' => 'Valitse projekti, josta kopioida tehtäviä',
    'The total maximum allowed attachments size is %sB.' => 'Sallittu liitteiden kokonaiskoko on %sB.',
    'Add attachments' => 'Lisää liitteitä',
    'Task #%d "%s" is overdue' => 'Tehtävä #%d "%s" on myöhässä',
    'Enable notifications by default for all new users' => 'Ota ilmoitukset käyttöön oletuksena kaikille uusille käyttäjille',
    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Määritä tehtävä sen luojalle tietyissä sarakkeissa, jos vastuuhenkilöä ei ole asetettu manuaalisesti',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Määritä tehtävä kirjautuneelle käyttäjälle siirrettäessä määritettyyn sarakkeeseen, jos käyttäjää ei ole määritetty',
];
